package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.26.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.26.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`MP`!````2",```````!``````````*BA````
M`````````$``.``)`$``&@`9``8````$````0`````````!``````````$``
M````````^`$```````#X`0````````@``````````P````0````X`@``````
M`#@"````````.`(````````;`````````!L``````````0`````````!````
M!0```````````````````````````````````)R9````````G)D`````````
M``$```````$````&`````)L`````````FP$```````";`0``````@`4`````
M``"H%0```````````0```````@````8````0FP```````!";`0``````$)L!
M``````!0`@```````%`"````````"``````````$````!````%0"````````
M5`(```````!4`@```````$0`````````1``````````$`````````%#E=&0$
M````R)(```````#(D@```````,B2````````W`````````#<``````````0`
M````````4>5T9`8`````````````````````````````````````````````
M````````````$`````````!2Y71D!`````";`````````)L!````````FP$`
M```````%``````````4````````!`````````"]L:6(O;&0M;&EN=7@M86%R
M8V@V-"YS;RXQ```$````$`````$```!'3E4```````,````'``````````0`
M```4`````P```$=.50#9CCCR%B%*S-9(+\+^\<=^O`E=EA$```!/````!```
M``@````A$!``!<`$A"@"$`&`AD"`@BD`!`D@!(F(H!A%N@0""$\```!0````
M5````%D```!:````80```&(```!C````90```&8`````````:````&D```!J
M````;````````````````:\TZ&[%WQ_JT^\.SMY'+6M_FGPNQ9NV=E0\E"#_
MY`ZXC?$.U634?-EQ6!SB1\8!K$OCP+KCDGQ8[Y=YPN4_+/JA;&"S`8MO:PE#
MUF>OS&9"1=7LB0=PTPT4XI[:S>.>,V+;[0TZEPM_J9R;OMI7&^&G`@JCX/M)
M```````````````````````````````````````````#``L`R!P`````````
M```````````````#`!8``*`!`````````````````!4#```2````````````
M`````````````"X#```2`````````````````````````+4"```2````````
M`````````````````.("```2`````````````````````````#8#```2````
M`````````````````````(D"```2`````````````````````````!$````@
M`````````````````````````,,"```2`````````````````````````(`"
M```2`````````````````````````.D"```B````````````````````````
M`*X"```2`````````````````````````)<"```2````````````````````
M`````+0````2`````````````````````````$0#```1````````````````
M`````````(,!```2`````````````````````````/@"```2````````````
M`````````````(0````2``````````````````````````P!```2````````
M`````````````````&("```2`````````````````````````%0"```2````
M`````````````````````*H!```2``````````````````````````$!```1
M`````````````````````````#\"```2`````````````````````````&<!
M```2`````````````````````````.,````1````````````````````````
M`#4!```2`````````````````````````&(#```2````````````````````
M`````!P#```2`````````````````````````*<"```2````````````````
M`````````,(````2`````````````````````````+$!```2````````````
M`````````````"("```2`````````````````````````)X!```2````````
M`````````````````/`!```2`````````````````````````)\"```2````
M`````````````````````-L"```2`````````````````````````(X"```2
M`````````````````````````%$#```2``````````````````````````0"
M```2`````````````````````````$,!```2````````````````````````
M`"T````@`````````````````````````)X#```1````````````````````
M`````$L#```2`````````````````````````-0"```2````````````````
M`````````+P!```1`````````````````````````&0````2````````````
M`````````````'`#```2`````````````````````````&\"```2````````
M`````````````````/\#```2`````````````````````````#D"```2````
M`````````````````````),````2`````````````````````````)\````2
M`````````````````````````%P!```2``````````````````````````H#
M```2`````````````````````````"(!```2````````````````````````
M`!$!```2`````````````````````````%8````2````````````````````
M`````'8"```2`````````````````````````!8!```2````````````````
M`````````),!```2`````````````````````````/`````2````````````
M`````````````$T"```2`````````````````````````'4!```2````````
M`````````````````',````2`````````````````````````"H"```2````
M`````````````````````+P"```2`````````````````````````'X#```1
M`````````````````````````(`#```1``````````````````````````H"
M```2`````````````````````````-0````2````````````````````````
M`%,!```2`````````````````````````,T"```2````````````````````
M`````#P````@`````````````````````````!$"```2````````````````
M`````````%L"```2`````````````````````````&H#```2````````````
M`````````````!P$```0`!<`J+`!``````````````````@$```2``T`4%$`
M``````"``````````,@#```2``X`9%(``````````````````$`$```2``T`
MB$0```````#8"````````"D#```2``T``"$```````!(`@```````,X#```2
M``T`L#T````````$`````````-\#```0`!<`@*`!`````````````````,<$
M```2``T`N#T````````,`@```````,$$```2``L`R!P`````````````````
M`/0$```2``T`8$T```````#L`P```````+,$```0`!<`@*`!````````````
M`````"<$```2``T`R#\````````L`````````%H$```1``\`>%(````````$
M`````````)D$```0`!<`J+`!`````````````````)X$```0`!<`J+`!````
M`````````````+\$```2``T`2#P````````X`````````-0$```2``T`F$,`
M``````#L`````````.8$```2``T`X$(```````"(`````````$T$```0`!8`
M`*`!`````````````````#0$```2``T`^#\````````<`0```````!0$```0
M`!8`@*`!`````````````````(\$```1`!8`>*`!```````(`````````+X#
M```2``T`8%(````````$`````````'\$```2``T`X%$```````"`````````
M`%,$```2``T`2",``````````````````$\$```@`!8``*`!````````````
M`````.T#```2``T`:$,````````L`````````!L$```0`!<`J+`!````````
M`````````&D$```2``T`V#P```````#8`````````*8$```2``T`&$$`````
M``#$`0````````!L:6)P97)L+G-O+C4N,C8`7TE435]D97)E9VES=&5R5$U#
M;&]N951A8FQE`%]?9VUO;E]S=&%R=%]?`%])5$U?<F5G:7-T97)434-L;VYE
M5&%B;&4`4&5R;%]S>7-?=&5R;0!097)L7W-Y<U]I;FET,P!097)L7V%T9F]R
M:U]L;V-K`'!E<FQ?8V]N<W1R=6-T`%!E<FQ?9V5T7W-V`%!E<FQ?8W)O86M?
M;F]C;VYT97AT`%!E<FQ?879?<VAI9G0`4&5R;%]S=E\R<'9?9FQA9W,`4&5R
M;%]S=E]S971P=FX`4$Q?9&]?=6YD=6UP`%!E<FQ?;F5W6%-?9FQA9W,`4$Q?
M=&AR7VME>0!P97)L7V9R964`4&5R;%]M9U]S970`4&5R;%]A=&9O<FM?=6YL
M;V-K`%!E<FQ?<W9?<V5T<'8`4&5R;%]G=E]F971C:'!V`'!E<FQ?<G5N`%!E
M<FQ?;F5W6%,`<&5R;%]D97-T<G5C=`!097)L7V%V7V9E=&-H`&)O;W1?1'EN
M84QO861E<@!P97)L7W!A<G-E`%!E<FQ?<V%F97-Y<VUA;&QO8P!P97)L7V%L
M;&]C`%!,7VUE;6]R>5]W<F%P`&QI8F1L+G-O+C(`;&EB;2YS;RXV`&QI8G!T
M:')E860N<V\N,`!P=&AR96%D7V=E='-P96-I9FEC`&-L;W-E`&]P96XV-`!?
M7V5R<FYO7VQO8V%T:6]N`&QS965K-C0`<F5A9`!L:6)C+G-O+C8`<FUD:7(`
M7U]S=')N8W!Y7V-H:P!S=')C:'(`9V5T<&ED`'5N;&EN:P!?7VUE;6-P>5]C
M:&L`<W1R8VUP`')E861D:7(V-`!R96%D;&EN:P!E>&ET`&-L;W-E9&ER`&]P
M96YD:7(`<F5A;&QO8P!M96US970`9V5T=6ED`'-T<G1O:P!M96UC:'(`7U]X
M<W1A=#8T`'-T<G-T<@!A8V-E<W,`<W1R9'5P`'-T<FQE;@!?7V-X85]F:6YA
M;&EZ90!?7W)E9VES=&5R7V%T9F]R:P!?7VQX<W1A=#8T`&UE;6-P>0!?7VQI
M8F-?<W1A<G1?;6%I;@!M96UM;W9E`%]?<W!R:6YT9E]C:&L`<W1D97)R`&%B
M;W)T`%]?<W1A8VM?8VAK7V9A:6P`<W1R;F-M<`!M:V1I<@!?7V9P<FEN=&9?
M8VAK`%]?96YV:7)O;@!L9"UL:6YU>"UA87)C:#8T+G-O+C$`7U]S=&%C:U]C
M:&M?9W5A<F0`;&EB8W)Y<'0N<V\N,0!?7VQI8F-?8W-U7V9I;FD`<&%R7V-U
M<G)E;G1?97AE8P!?7V)S<U]S=&%R=%]?`&=E=%]U<V5R;F%M95]F<F]M7V=E
M='!W=6ED`'!A<E]C;&5A;G5P`%]E9&%T80!?7V)S<U]E;F1?7P!P87)?8F%S
M96YA;64`<&%R7V1I<FYA;64`<&%R7VUK=&UP9&ER`%]?9&%T85]S=&%R=`!?
M24]?<W1D:6Y?=7-E9`!P87)?8W5R<F5N=%]E>&5C7W!R;V,`7U]L:6)C7V-S
M=5]I;FET`&UY7W!A<E]P;`!?96YD`%]?96YD7U\`<&%R7VEN:71?96YV`%]?
M8G-S7W-T87)T`'AS7VEN:70`<&%R7V9I;F1P<F]G`'!A<E]S971U<%]L:6)P
M871H`'!A<E]E;G9?8VQE86X`6%-?26YT97)N86QS7U!!4E]"3T]4`$=,24)#
M7S(N,3<```````````(``@`"``(``@`"`````@`"``(``@`"`````@````(`
M``````(``@`"`````@`````````"``(``@```````P````,``@`"``(``@`#
M```````$``(``@```````@`"``(``@`````````"`````@````(`````````
M`@```````P`"``(``@`#```````"`````P`"``(``0`!``$``0`!``$``0`!
M``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$`
M`0`!`(@#```0````(````)>1E@8```0`"@4````````!``$`X`$``!`````@
M````EY&6!@```P`*!0````````$``0`O`@``$`````````"7D98&```"``H%
M`````````)L!```````#!````````$@D````````")L!```````#!```````
M```D````````@)\!```````#!````````&!2````````T)\!```````#!```
M`````.!1````````X)\!```````#!``````````A````````"*`!```````#
M!`````````B@`0``````&*`!```````#!````````(A6````````(*`!````
M```#!````````+A2````````,*`!```````#!````````!A4````````.*`!
M```````#!````````&A6````````0*`!```````#!````````'!6````````
M2*`!```````#!````````'A6````````4*`!```````#!````````(!6````
M````8*`!```````#!````````%!6````````:*`!```````#!````````%A6
M````````>*`!```````#!````````)!6````````B)\!```````!!```"0``
M````````````D)\!```````!!```#```````````````F)\!```````!!```
M$```````````````H)\!```````!!```$0``````````````J)\!```````!
M!```&```````````````L)\!```````!!```&P``````````````N)\!````
M```!!```*P``````````````P)\!```````!!```+```````````````R)\!
M```````!!```+P``````````````V)\!```````!!```.0``````````````
MZ)\!```````!!```0@``````````````\)\!```````!!```1@``````````
M````^)\!```````!!```2P``````````````>)T!```````"!````P``````
M````````@)T!```````"!```!```````````````B)T!```````"!```!0``
M````````````D)T!```````"!```!@``````````````F)T!```````"!```
M!P``````````````H)T!```````"!```"```````````````J)T!```````"
M!```"@``````````````L)T!```````"!```"P``````````````N)T!````
M```"!```#```````````````P)T!```````"!```#0``````````````R)T!
M```````"!```#@``````````````T)T!```````"!```#P``````````````
MV)T!```````"!```$@``````````````X)T!```````"!```$P``````````
M````Z)T!```````"!```%```````````````\)T!```````"!```%0``````
M````````^)T!```````"!```%@```````````````)X!```````"!```%P``
M````````````")X!```````"!```&0``````````````$)X!```````"!```
M&@``````````````&)X!```````"!```'```````````````()X!```````"
M!```'0``````````````*)X!```````"!```'@``````````````,)X!````
M```"!```'P``````````````.)X!```````"!```(```````````````0)X!
M```````"!```(0``````````````2)X!```````"!```(@``````````````
M4)X!```````"!```(P``````````````6)X!```````"!```)```````````
M````8)X!```````"!```)0``````````````:)X!```````"!```)@``````
M````````<)X!```````"!```)P``````````````>)X!```````"!```*```
M````````````@)X!```````"!```*0``````````````B)X!```````"!```
M*@``````````````D)X!```````"!```*P``````````````F)X!```````"
M!```+0``````````````H)X!```````"!```+@``````````````J)X!````
M```"!```,```````````````L)X!```````"!```,0``````````````N)X!
M```````"!```,@``````````````P)X!```````"!```,P``````````````
MR)X!```````"!```-```````````````T)X!```````"!```-0``````````
M````V)X!```````"!```-@``````````````X)X!```````"!```-P``````
M````````Z)X!```````"!```.```````````````\)X!```````"!```.@``
M````````````^)X!```````"!```.P```````````````)\!```````"!```
M/```````````````")\!```````"!```/0``````````````$)\!```````"
M!```/@``````````````&)\!```````"!```/P``````````````()\!````
M```"!```0```````````````*)\!```````"!```00``````````````,)\!
M```````"!```0P``````````````.)\!```````"!```1```````````````
M0)\!```````"!```1P``````````````2)\!```````"!```2```````````
M````4)\!```````"!```20``````````````6)\!```````"!```2@``````
M````````8)\!```````"!```3```````````````:)\!```````"!```30``
M````````````<)\!```````"!```3@``````````````_7N_J?T#`)&L`0"4
M_7O!J,`#7]8`````\'N_J=```)`1ND;Y$,(UD2`"']8?(`/5'R`#U1\@`]70
M``"0$;Y&^1#B-9$@`A_6T```D!'"1OD0`C:1(`(?UM```)`1QD;Y$"(VD2`"
M'];0``"0$<I&^1!"-I$@`A_6T```D!'.1OD08C:1(`(?UM```)`1TD;Y$((V
MD2`"'];0``"0$=9&^1"B-I$@`A_6T```D!':1OD0PC:1(`(?UM```)`1WD;Y
M$.(VD2`"'];0``"0$>)&^1`"-Y$@`A_6T```D!'F1OD0(C>1(`(?UM```)`1
MZD;Y$$(WD2`"'];0``"0$>Y&^1!B-Y$@`A_6T```D!'R1OD0@C>1(`(?UM``
M`)`1]D;Y$*(WD2`"'];0``"0$?I&^1#"-Y$@`A_6T```D!'^1OD0XC>1(`(?
MUM```)`1`D?Y$`(XD2`"'];0``"0$09'^1`B.)$@`A_6T```D!$*1_D00CB1
M(`(?UM```)`1#D?Y$&(XD2`"'];0``"0$1)'^1"".)$@`A_6T```D!$61_D0
MHCB1(`(?UM```)`1&D?Y$,(XD2`"'];0``"0$1Y'^1#B.)$@`A_6T```D!$B
M1_D0`CF1(`(?UM```)`1)D?Y$"(YD2`"'];0``"0$2I'^1!".9$@`A_6T```
MD!$N1_D08CF1(`(?UM```)`1,D?Y$((YD2`"'];0``"0$39'^1"B.9$@`A_6
MT```D!$Z1_D0PCF1(`(?UM```)`1/D?Y$.(YD2`"'];0``"0$4)'^1`".I$@
M`A_6T```D!%&1_D0(CJ1(`(?UM```)`12D?Y$$(ZD2`"'];0``"0$4Y'^1!B
M.I$@`A_6T```D!%21_D0@CJ1(`(?UM```)`15D?Y$*(ZD2`"'];0``"0$5I'
M^1#".I$@`A_6T```D!%>1_D0XCJ1(`(?UM```)`18D?Y$`([D2`"'];0``"0
M$69'^1`B.Y$@`A_6T```D!%J1_D00CN1(`(?UM```)`1;D?Y$&([D2`"'];0
M``"0$7)'^1"".Y$@`A_6T```D!%V1_D0HCN1(`(?UM```)`1>D?Y$,([D2`"
M']:P``#P$7Y'^1#B.Y$@`A_6L```\!&"1_D0`CR1(`(?UK```/`1AD?Y$"(\
MD2`"']:P``#P$8I'^1!"/)$@`A_6L```\!&.1_D08CR1(`(?UK```/`1DD?Y
M$((\D2`"']:P``#P$99'^1"B/)$@`A_6L```\!&:1_D0PCR1(`(?UK```/`1
MGD?Y$.(\D2`"']:P``#P$:)'^1`"/9$@`A_6L```\!&F1_D0(CV1(`(?UK``
M`/`1JD?Y$$(]D2`"']:P``#P$:Y'^1!B/9$@`A_6L```\!&R1_D0@CV1(`(?
MUK```/`1MD?Y$*(]D2`"']:P``#P$;I'^1#"/9$@`A_6_7NYJ?T#`)'S4P&I
MLP``\+0``/!CXD?YXH<$J>(C`9%D`$#YY#<`^00`@-+A0P&1X%\`N>!S`9&*
M__^7H```\*(``/``]$?Y0NQ'^>$#`JH@#`"4H```\`#81_D``$`Y8`$`-4O_
M_Y?"``"00%``^2`.`+2T``#P%O__EX#61_D``$"Y3___EQ^$)#F4UD?Y@`)`
MN4O__Y<!Z%,Y(0`?,@'H$SF``D"Y1O__EP+H4SGA7T"Y`P#\DD(``#("Z!,Y
M(10`$?5;`JGW&P#Y(7Q`DS\``^MH"@!4(/!]TS7__Y?E*T#YP0``D-0``)"$
M(@*1)SQ`^0(``/!"(!F1A@"`4J$`0/D#``#P8P`9D0$,`*DA`(#2A@0`N>8`
M@)*`!`#Y!P@!J>)?0+E?!`!Q#0$`5",0`!&D>&'XP\PCBR$$`)%?``%K!&@C
M^$S__U1%$``1EB("D>,#`*I"#``1!<PEBP$``+#`#D#Y(0`RD;^`'_@$`(#2
M;___E_4#`"H@`P`TEB("D?>3`9'`#D#YZ?[_EP```/#A`Q>J`*`.D:,$`)2`
M`@"TE"("D8`.0/G-_O^75/__EW/B1_G@`Q4JXC=`^6$"0/E!``'*X0,`M?-3
M0:GU6T*I]QM`^?U[QZC``U_6P`Y`^7/__Y?U`P`JY?__%\`*0/E@``"TE@L`
ME.K__Q?A`Q>J````\`#`#)&'!`"4P`H`^8#\_[2."P"4XO__%Z$``/````#P
M`.`8D2'D1_DD__^7(`"`4O5;`JGW&P#YA/[_E^_^_Y<=`(#2'@"`TN4#`*KA
M`T#YXB,`D>8#`)&@``#P`/!'^:,``/!CZ$?YI```\(3`1_FZ_O^7\?[_EZ``
M`/``W$?Y0```M.G^_Q?``U_6'R`#U<```)````*1P0``D"$``I$_``#KH```
M5*$``/`AQ$?Y00``M"``'];``U_6'R`#U<```)````*1P0``D"$``I$A``#+
M(?Q#DR'\08LA_$&3H0``M*(``/!"_$?Y0@``M$``'];``U_6_7N^J?T#`)'S
M"P#YTP``D&`"0CE``0`UH```\`#(1_F```"TP```D``$0/E5_O^7VO__ER``
M@%)@`@(Y\PM`^?U[PJC``U_6X/__%Q\@`]7_@PK1J```\.)C`)$%X`"1">`!
MD>0#`JK]>P"I_0,`D0'A1_DC`$#YXT\!^0,`@-*A`$"YA$``D:.$0/@A",!:
M@0`?^+\`">MA_&#39_QHT^<<>)(FW'C3(1P(4\8<<)+CX$.J(0`&JB$``ZJ!
M@!_X`?[_5$4`")%!`$#Y0B``D4,$0/E$'$#Y8P`!RD$P0/DA``3*(0`#RB/\
M7]-A!`&J(7Q`DD$\`/E?``7K8?[_5`400*DC,X_2!AQ!J4-0J_+KLT&I(G2=
MTJK\6].M_$+32A4%JJUY!:KA``;*(MNM\B$`!(HA``?*:P$#BRI`*HN!_$+3
M(7@$JDH!"XL)$$#Y+GQ`DLL!!LJ,`0.+2@$)"VL!!8IK`0;*(0`-RD_]6]-K
M`0>+[Q4*JFL!#(OK`0L+3_U"TR$`"HKJ>0JJ[+]"J2$`#LIP_5O3(0`&BQ`6
M"ZJ,`0.+[P$#BR$`#(NL`0K*`0(!"XP!"XJP?4"2;?U"TXP!$,JM>0NJC`$.
MBR[\6].,`0^+2P$-RLX5`:I*?4"2[Q]`^<X!#`MK`0&*+/Q"TVL!"LKO`0.+
M:P$0B]#]6].,>0&J$!8.JFL!#XNA`0S*"P(+"]#]0M,A``Z*#GH.JN]#1*FM
M?4"2(0`-RB$`"HOJ`0.+;_U;TR$`"HN*`0[*[Q4+JHQ]0))*`0N*[P$!"TH!
M#,IA_4+3$`(#BRMX"ZI*`0V+P0$+RDH!$(O.?4"2\"M`^>W]6],A``^*K14/
MJB$`#LKQ_4+3K0$*"R]Z#ZH*`@.+(0`,BR$`"HMJ`0_*L/U;TVM]0))*`0V*
M$!8-JDH!"\H0`@$+2@$.B[']0M/ANT6I+7H-J@S^6],1_D+3C!40JB$``XM*
M`0&+X0$-RB$`$(KO?4"2(0`/RHP!"@LP>A"JR@$#BR$`"XN._5O3(0`*BZH!
M$,I*`0R*K7U`DLX5#*I*`0W*S@$!"TH!#XOAOT:ID?U"TRQZ#*K+_5O3:Q4.
MJM']0M,A``.+2@$!BP$"#,HA``Z*$'Y`DB$`$,IK`0H++GH.JNH!`XLA``V+
M;_U;TR$`"HN*`0[*2@$+BHQ]0)+O%0NJ2@$,RN\!`0M*`1"+X<-'J7']0M,K
M>@NJ[?U;TZT5#ZKQ_4+3(0`#BTH!`8O!`0O*(0`/BLY]0)(A``[*K0$*"R]Z
M#ZH*`@.+(0`,B[#]6],A``J+:@$/RDH!#8IK?4"2$!8-JDH!"\H0`@$+2@$.
MB^&[2*FQ_4+3+7H-J@S^6].,%1"J$?Y"TR$``XM*`0&+X0$-RB$`$(KO?4"2
M(0`/RHP!"@LP>A"JR@$#BR$`"XN._5O3(0`*BZH!$,I*`0R*K7U`DLX5#*I*
M`0W*S@$!"TH!#XOAOTFID?U"TRQZ#*K+_5O3:Q4.JB$``XOO`0.+2@$!BP$"
M#,IK`0H+$'Y`DB$`#HHA`!#*:OU;TR$`#8O-_4+3KGD.JB$`#XM*%0NJTGU`
MDDH!`0N!`0[*(0`+BHQ]0)(A``S*4?U;TR$`$(LQ%@JJ[<-*J:T!`XL#`@.+
M(0`-BVW]0M,Q0#&+JWD+JB]^0)+!`0O*(0`*BNW]6],A`!+*(0`,BZT5#ZHA
M``.+0_U"TRU`+8MA>`JJL'U`DFH!`<KC7T#Y2@$12@[^6]-*`1*+8P`"B\X5
M$*I*`0.+[/U"TTY!+HN,>0^JT7U`DB\`#,KJ8T#Y[P$-2BW^6]/K02N+2@$"
MBZT5$:IC`0J+"OY"TVU`+8M#>1"JL'U`DHH!`\KO9T#Y2@$.2@O^6]-*02&+
M:Q40JN$!`HM*`0&+(?Y"TTM!*XLJ>!&J;WU`DF$`"LKN:T#Y(0`-2NW]6],A
M0"R+S@$"BZP5#ZHA``Z+#?Y"TRQ`+(NA>1"JD'U`DDX!`<KM;T#YS@$+2@O^
M6]/#02.+K0$"BVL5$*IC``V+[?U"TVM`*XNC>0^J;WU`DBX``\KM<T#YS@$,
M2NS]6]/*02J+K0$"BXP5#ZI*`0V+#?Y"TTQ!+(NJ>1"JD'U`DFX`"LKM=T#Y
MS@$+2@O^6]/!02&+K0$"BVL5$*HA``V+[?U"TRM`*XNA>0^J;WU`DDX!`<KM
M>T#YS@$,2NS]6]/#02.+K0$"BXP5#ZIC``V+#?Y"TVQ`+(NC>1"JD'U`DBX`
M`\KM?T#YS@$+2@O^6]/*02J+K0$"BVL5$*I*`0V+[?U"TTM!*XNJ>0^J;WU`
MDFX`"LKM@T#YS@$,2NS]6]/!02&+K0$"BXP5#ZHA``V+#?Y"TRQ`+(NA>1"J
M3@$!RI!]0)+.`0M*PT$CBPO^6]/MNU"I:Q40JJT!`HMC``V+[?U"TVM`*XNC
M>0^J;WU`DBT``\JL`0Q*[?U;TXI!*HNM%0^JS`$"BTH!#(L,_D+334$MBXIY
M$*JP?4"2;``*RNZ/0/F+`0M*#/Y;TV%!(8N,%1"JRP$"BR$`"XOK_4+3+$`L
MBV%Y#ZJ+?4"23P$!RNZ30/GO`0U*;?U;T^-!(XO.`0*+K14+JF,`#HL._D+3
M;4`MB\-Y$*JP?4"2+P`#RNZ70/GO`0Q*#/Y;T^I!*HO.`0*+C!40JDH!#HMN
M_4+33$$LB\MY"ZJ*?4"2;P`+RNZ;0/GO`0U*3?U;T^%!(8O.`0*+K14*JB$`
M#HL._D+3+4`MB\%Y$*KNGT#Y;P$!RN\!#$JP?4"2S@$"B^-!(XMC``Z+3OU"
MT\IY"JH,_EO3+P`*RHP5$*KO`0U*ZT$KBVQ`+(ON/U2I@WU`DFW\6].M%0.J
MS@$"B^\!`HMK`0Z+#OY"TVU!+8O+>1"J4`$+RJY]0)(,`@Q*</Q"TX%!(8O,
M_5O3`WH#JB$`#XN,%0ZJ[ZM`^8P!`0MA`0/*+0`-2L']0M,A>`ZJJD$JB^(!
M`HN-_5O3,7Q`DJX5#*I"`0*+;7Q`DFH``:K.`0(+[Z]`^:(!$8I*`0R*@_U"
MTTH!`JJ"FY?28N.Q\F-X#*I+02N+Z@$"BVQ\0))K`0J+*@`#JB$"#(I*`0Z*
MT/U;TTH!`:H0%@ZJ2@$-BQ`""POO-U:IP?U"TR%X#JHN?$"2ZP$"BP_^6]-*
M`0N+[Q40JFL``:KO`0H+@P$.BFL!$(IK`0.J`_Y"TZH!`HMC>!"J:P$1B^W]
M6]-P?$"2:P$*BZT5#ZHJ``.J\;M`^:T!"PO!`1"*2@$/BDH!`:KA_4+3(7@/
MJBL"`HM*`0R+K/U;TR]\0))*`0N+C!4-JFL``:KQOT#YC`$*"P,"#XIK`0V*
M:P$#JJ/]0M-C>`VJBOU;TVL!#HLN`@*+314,JFL!#HLJ``.J;GQ`DO'#0/FM
M`0L+X0$.BDH!#(I*`0&J@?U"TR%X#*JK_5O32@$0BS`"`HML%0VJ2@$0BVL`
M`:HP?$"2\<=`^8P!"@O#`1"*:P$-BFL!`ZJC_4+38W@-JHK]6]-K`0^++P("
MBTT5#*IK`0^+*@`#JF]\0)+QRT#YK0$+"P$"#XI*`0R*2@$!JH']0M,A>`RJ
MJ_U;TTH!#HLN`@*+;!4-JDH!#HMK``&J+GQ`DO'/0/F,`0H+XP$.BFL!#8IK
M`0.JH_U"TV-X#:J*_5O3:P$0BS`"`HM-%0RJ:P$0BRH``ZIP?$"2\=-`^:T!
M"PO!`1"*2@$,BDH!`:J!_4+3(7@,JJO]6]-*`0^++P("BVP5#:I*`0^+:P`!
MJB]\0)+QUT#YC`$*"P,"#XIK`0V*:P$#JJ/]0M-C>`VJ*@("BVL!#HN._5O3
M;7Q`DFL!"HO.%0RJ*@`#JO';0/G.`0L+X0$-BDH!#(I*`0&J@?U"TR%X#*K+
M_5O32@$0BS`"`HML%0ZJ2@$0BVL``:HP?$"2\=]`^8P!"@NC`1"*:P$.BFL!
M`ZK#_4+38W@.JHK]6]-K`0^++P("BTX5#*IK`0^+*@`#JF]\0)+QXT#Y`0(/
MBDH!#(K.`0L+2@$!JH']0M,A>`RJ*P("BTH!#8LL?$"22@$+BVL``:IK`0Z*
MXP$,BFL!`ZK-_5O3:P$0BZT5#JKQPURIK0$*"\/]0M-C>`ZJ;GQ`DBH"`HNQ
M_5O3,18-JFL!"HLJ``.J*P(+"X$!#HI*`0V*2@$!JJ']0M,A>`VJ$`("BTH!
M#XMO_5O3+7Q`DDH!$(OO%0NJ8P`!JO#O0/GO`0H+8P`+BLH!#8IC``JJ:OU"
MTTIY"ZIC``R+\?U;TPP"`HLQ%@^J*P`*JF,`#(M,?4"2(0(#"VL!#XJC`0R*
M:P$#JN/]0M-C>`^J:P$.B_`_7JDN_%O3SA4!JDH!`ZI*`0&*\?M`^1`"`HMK
M`1"+RP$+"VY\0)*0`0Z*2@$0JG#]6]-*`0V+$!8+JNT!`HLB`@*+2@$-BRW\
M0M.A>0&J4$$PBPI^0)(O?$"28P`!JLT!#XIC``N*<OU"TV,`#:I-_5O38P`,
MBZT5"JIB``*+2WH+JDU`+8LA``O*L7U`DB$`$$KB_T#YPSJ8TBS^6]-#3+GR
M(0`.BT(``XN,%1&J(0`"BT[]0M,L0"R+RGD*JI!]0))B`0K*X0-!^4(`#4H-
M_EO30@`/BR$``XNM%1"J0@`!BR[^0M--0"V+P7D1JJY]0))/`0'*X@=!^>\!
M#$K,_5O3ZT$KBT(``XN,%0ZJ:P$"BP_^0M-L02R+XGD0JH]]0)(P``+*ZPM!
M^1`"#4KM_5O3"D(JBVL!`XNM%0^J2@$+B]#]0M--02V+"WH.JJY]0))0``O*
MZ@]!^1`"#$K,_5O3`4(ABTH!`XN,%0ZJ(0`*B_#]0M,L0"R+"GH/JH]]0))P
M`0K*X1-!^1`"#4KM_5O3`D(BBR$``XNM%0^J0@`!B]#]0M--0"V+`7H.JJY]
M0))0`0'*XA=!^1`"#$K,_5O3"T(KBT(``XN,%0ZJ:P$"B_#]0M-L02R+`GH/
MJH]]0)(P``+*ZQM!^1`"#4KM_5O3"D(JBVL!`XNM%0^J2@$+B]#]0M--02V+
M"WH.JJY]0))0``O*ZA]!^1`"#$K,_5O3`4(ABTH!`XN,%0ZJ(0`*B_#]0M,L
M0"R+"GH/JH]]0))P`0K*X2-!^1`"#4KM_5O3`D(BBR$``XNM%0^J0@`!B]#]
M0M--0"V+`7H.JJY]0))0`0'*XB=!^1`"#$K,_5O3"T(KBT(``XN,%0ZJ:P$"
MB_#]0M-L02R+`GH/JH]]0)(P``+*ZRM!^1`"#4KM_5O3"D(JBVL!`XNM%0^J
M2@$+B]#]0M--02V+"WH.JJY]0))0``O*ZB]!^1`"#$K,_5O3`4(ABTH!`XN,
M%0ZJ(0`*B_#]0M,L0"R+"GH/JH]]0))P`0K*X3-!^1`"#4KM_5O3`D(BBR$`
M`XNM%0^J0@`!B]#]0M--0"V+`7H.JJY]0))0`0'*XC=!^1`"#$K,_5O3"T(K
MBXP5#JI"``.+:P$"B_#]0M-K02R+`GH/JF]]0)(P``+*[#M!^1`"#4KM_5O3
M"D(JBXP!`XO0_4+3K14/JDH!#(L,>@ZJ34$MBU``#,JN?4"2$`(+2NL_0?G*
M_5O3`4(ABTH5#JIK`0.+\/U"TR$`"XL+>@^J*D`JBY`!"\I!?4"2$`(-2N]#
M0?DM_%O3`D(BBZT5`:KO`0.+T/U"TT(`#XL.>@ZJ34`MBW`!#LKO1T'YHGU`
MD@H""DHP_$+3[P$#BTQ!+(M*_%O3`7H!JHP!#XM*%0*J[TM!^4H!#`O,`0'*
M4/Q"TXT!#4KL`0.+JT$KBT/]6]-K`0R+8Q0*J@)Z`JIC``L+".%'^48`!@ME
M``4+R0$)"X0`"@LA``<+!1``J08$`:GC3T'Y`@%`^6(``LH)$`#Y@@``M?U[
M0*G_@PJ1P`-?UGCZ_Y<?(`/5_7N\J?T#`)'S4P&IH`8`M*(``-#W8P.I0OA'
M^5@`0/E8!@"T]5L"J14`@%("`$`Y7_0`<4080'H!`P!4$P-`^1,"`+3W`P&J
M]@,`JK5^0)/T`QBJ'R`#U>(#%:KA`Q:JX`,3JC'Z_Y>````U8&IU.!_T`'$`
M`@!4DXY`^//^_[7U6T*I]V-#J>`#$ZKS4T&I_7O$J,`#7];U`P"JHAY`.%_T
M`'%$&$!ZH?__5+4"`$OC__\7@`(8R[4&`)%S`A6+`/Q#D^`"`+G@`Q.J\U-!
MJ?5;0JGW8T.I_7O$J,`#7]83`(#2Z?__%Q,`@-+W8T.IYO__%Q\@`]7]>[RI
M_0,`D?5;`JFV``#0]0,`JL#B1_GS4P&ILP``T/33`)$!`$#YX1\`^0$`@-)S
M^D?YX0,4JN`#%:JS__^7``(`M&("0/GC-X"Y0`P#BP$$0/E!>"/XX?[_M!\@
M`]4`(`"1`01`^0$``/FA__^UX0,4JN`#%:JD__^70/[_M=;B1_GA'T#YP`)`
M^2```,J@``"U\U-!J?5;0JG]>\2HP`-?U@_Z_Y?]>[FI_0,`D?-3`:FT``#0
M\P,`JO5;`JGU`P&J]V,#J?EK!*F!XD?YH`)`.2(`0/GB-P#Y`@"`TA_T`'&U
M%I6:X`,5JHGY_Y?V`P"JX9,!D>`#$ZJ#__^78`@`M/<#`*J"^?^7'P`6ZP('
M`%3X9X"YN0``T!CS?=-@`D`Y'_0`<0080'J@#`!4X0,3JA\@`]4@'$`X'_0`
M<0080'JA__]4(0`3RR%\0),Y^T?YP`H`D0```8LV`T#YI/G_E\!J./B`"P"T
MXV>`N>`#$ZHB`T#Y`11`.$)X8_@_]`!Q)!A`>D$``#G```!4`11`.$$<`#@_
M]`!Q)!A`>H'__U2A!X!2``"`TD$4`#BA:F`X06@@.``$`)&A__\U``"`4I3B
M1_GB-T#Y@0)`^4$``<IA"`"U\U-!J?5;0JGW8T.I^6M$J?U[QZC``U_6``"`
MTA\@`]6A:F`XX6H@.``$`)&A__\U[O__%[D``-#[*P#Y(/M'^1@`0/D``T#Y
M0`4`M.$#&*H``(!2`@``%.`#%RHBC$#X%P0`$:+__[4`#``1`'Q]DZ$``/`B
MB$"Y0@(`-2(`@%(BB`"Y9?G_E_L#`*J``P"T^GY`D^$#&*I8\WW3X@,8JA[Y
M_Y<@^T?Y&P``^5H'`)%_>SKX]V<`N?LK0/FC__\7X0,`JN`#&*J$^?^7^P,`
MJB#[1_D;``#Y.P$`M/I^0)-8\WW3\O__%P$`@-*C__\7``*`TA<`@%+>__\7
M^RM`^0``@!*Z__\7^RL`^7_Y_Y?]>[*I_0,`D?-3`:FT``#0@>)'^2(`0/GB
M;P#Y`@"`TL```+3U6P*I]0,`J@$`0#E!`0`U]5M"J93B1_GA;T#Y@`)`^2``
M`,K@"`"U\U-!J?U[SJC``U_6$/G_E_8#`*J@_O^T]V,#J1<``-`8``#0]^(*
MD1@#"Y'Y:P2I^F,!D>`#%JJA^?^7@`4`M!-,`)'A`Q>JX`,3JGCY_Y<@__\T
MX0,8JN`#$ZIT^?^7H/[_-.`#%:K=^/^7^0,`JN`#$ZK:^/^7```9"P`(`!$`
M?$"3#OG_E^4#$ZKD`Q6J`P``T&,@"Y'Y`P"J`@"`DB$`@%+2^/^7X@,:JN$#
M&:H``(!2UOC_EQ\$`#&@``!4X&M`N0`,%!(?$$!Q``(`5.`#&:JN^?^7X`,9
MJG#Y_Y?@`Q:J=OG_E\#Z_[7@`Q:J*_G_E^`#%:I5^?^7]5M"J?=C0ZGY:T2I
MN?__%^`#&:JI__^7\?__%_5;`JGW8P.I^6L$J2+Y_Y<?(`/5_7NUJ>$#`*K]
M`P"1\U,!J;,``-#T`P"J8^)'^>*C`)$``(!29`!`^>17`/D$`(#23/G_E^`!
M`#7A.T"Y`@"44B$,%!(_$$!Q)!!">F`!`%1SXD?YXE=`^6$"0/E!``'*@0$`
MM?-30:G]>\NHP`-?U@``@%+W__\7X`,4JD$`@%(4^?^7'P``<>`7GQKQ__\7
M_/C_EQ\@`]40"H+2_V,PR^+_@=+]>P"I_0,`D?-3`:FS``#08^)'^?5;`JGU
M(P&1]V,#J?8#`*KX`P&J9`!`^>0G"/D$`(#2X0,5J@```-``0`N1@_C_EQ\`
M`'&M!0!4`@0`4:$``-`AU$?YH\IB.#<`0+E#`P`U`@0`-%1\0)/A!8!2X@,4
MJN`#%:HY^?^70`,`M.`#%RK&^/^7XP,4JN(#%:KA`Q:J.OG_EW/B1_GA)TCY
M8`)`^2```,K``P"U$`J"TOU[0*GS4T&I]5M"J?=C0ZG_8S"+P`-?UN(#`"KA
M!8!2X`,5JE1\0)/B`Q2J(/G_EP#]_[7@`Q<JK?C_E^(#&*KA`Q:JBOC_E^C_
M_Q>@``#0`-1'^1<`0+G@`Q<JI/C_E^(#&*KA`Q:J@?C_E]___Q>O^/^7_7N_
MJ:```-#]`P"1`-1'^0``0+F9^/^7H@``T`,``-#]>\&H`0``T$+01_EC``J1
M(8`+D=7X_Q?]>[ZI_0,`D?,+`/FS``#0<]9'^6`"0+F*^/^7Z___EV`"0+F'
M^/^7\PM`^00``-#]>\*HA,`8D0(``+#C`P2J0H`UD0$``-`%`(!2(0`,D=SX
M_Q<?(`/5$`J$TO]C,,L`"(+2_7L`J?T#`)'S4P&ILP``T/3C`)'U6P*I]F,@
MBQ4`@-)@XD?Y`0!`^>$G$/D!`(#2._C_E^0#`"H%``#0`P``T*5@#)%C@`R1
M(@""TB$`@%+@`Q2J`OC_E^`#%*KA`Q:J`@""T@KX_Y>``?@W]`,`J@`$`!$`
M?$"3+?C_E_4#`*K```"TE'Y`D^$#%JKB`Q2JX_?_E[]J-#ASXD?YX`,5JN(G
M4/EA`D#Y00`!RN$``+40"H32_7M`J?-30:GU6T*I_V,PB\`#7]95^/^7RO__
M%Q\@`]40'H+2_V,PR_U[`*G]`P"1]V,#J;@``-`"XT?Y\U,!J?,#`:K[*P#Y
MX9,!D?L#`*H```#00P!`^>-W"/D#`(#2`,`,D<O]_Y?T`P"JX06`4N`#&ZJ1
M^/^70`(`M````-#A`QNJ```-D2K^_Y?@`QNJ&.-'^>)W2/D!`T#Y00`!R@$,
M`+40'H+2_7M`J?-30:GW8T.I^RM`^?]C,(O``U_6X`,;JO5;`JD6``#0^6L$
MJ;+W_Y?!0@V1^0,`*N`#$ZJJ]_^7\P,`JJ`&`+0:``#0%P``T%KC"I'W8@V1
M]:,#D6$"0#DA!@`TM```M.$#$ZK@`Q2J-?C_EX`$`#3@`Q.JGO?_EV+"((OA
M`P`J0/!?.!^\`''A``!4(00`46+"(8M_RB$X0O!?.%^\`'%@__]4(@<`$4$`
M`0L__#]Q#`,`5.0#$ZH#``#0Y@,;JF.`#9'E`Q>J`@""TB$`@%+@`Q6JBO?_
ME^*C`9'A`Q6J``"`4H[W_Y>@```UX7M`N2$,%!(_($!Q0`(`5,%"#9$``(#2
M=O?_E_,#`*I`^O^U]5M"J?EK1*FN__\7U```M.$#&JK@`Q2J!?C_EX#^_S0?
M(`/5\P,:JB$`@%+:__\7(0"`4N`#%:KQ]_^7@/W_->$#%:H```#0```-D<K]
M_Y?@`Q6JSO?_E_5;0JGY:T2IG?__%_5;`JGY:P2IT/?_EQ\@`]4!`$`YX@,`
MJN$``#0?(`/5``0`D3^\`'%"$(":`0!`.8'__S7@`P*JP`-?UA\@`]6`"`"T
M_7N^J?T#`)'S"P#Y\P,`J@$`0#DA!P`T1_?_EP`$`-%B`@"+?P("ZR(#`%1@
M:F`X'[P`<:```%02```40`!`.1^\`''A`0!40@0`T7\"`NMA__]40`!`.1^\
M`''@!`!4\PM`^0```+#]>\*H`&`-D9WW_Q=``$`Y'[P`<:`!`%1"!`#1?P("
MZV/__U1_`@+K(/[_5$($`-%_`@+K`@$`5!\@`]5``$`Y'[P`<8$``%1"!`#1
M?P("ZV/__U1"`!/+``"`TD$(`)$_!$#Q"`$`5*```-`$H`*10@0`D>$#$ZK@
M`P2J`P""TD_W_Y?S"T#Y_7O"J,`#7];S"T#Y````L/U[PJ@`X`J1=_?_%P``
M`+``X`J1=/?_%Q\@`]7]>[BI`0``L"$`"I']`P"1\U,!J;,``+````"P8^)'
M^?5;`JD`H`V1]V,#J18``+`7``"P9@!`^>8_`/D&`(#2&```L"8<0:GF'P6I
M%```L"040JGD%P:I(6!`>>'C`'F4(@^1]3,!D2C]_Y<```"P`.`-D27]_Y<`
M``"P```.D2+]_Y<```"P`$`.D1_]_Y?`8@Z1'?W_EP```+``H`Z1&OW_E^#"
M#)$8_?^7`.,.D1;]_Y?@`Q2J%/W_EP```+``8`^1$?W_EP```+````V1#OW_
MEP```+#A`Q6J`*`/D<S\_Y>```"TX0,`JN`#%*HP_?^7````L.$#%:H``!"1
MQ/S_EZ```+3A`P"J````L`!@$)$G_?^7````L.$#%:H`H!"1N_S_ET`"`+3A
M`P"JX,(,D1_]_Y?`8@Z1`0``L"&`$9$;_?^7<^)'^>$_0/E@`D#Y(```RD`#
M`+7S4T&I]5M"J?=C0ZG]>\BHP`-?U@```+#A`Q6J`.`0D:7\_Y>@``"TX0,`
MJ@#C#I$)_?^7ZO__%P$``+#T0P&1X(<!D2%`$9%"`8#2Y/;_EV#\_S6!;@"1
M`.,.D?[\_Y??__\7"O?_EQ\@`]7]>[VI_0,`D?-3`:FS``"PM```T&'B1_F`
M$D"Y(@!`^>(7`/D"`(#2'P0`,2`!`%1SXD?YXA=`^6$"0/E!``'*(0(`M?-3
M0:G]>\.HP`-?UN&3`)$```"P`.`.D7O\_Y?A`P"J``"`4J$``+0@`$`Y'\``
M<0080'K@!Y\:@!(`N>S__Q?G]O^7_7N_J?T#`)&(]O^7!_?_EX```+3]>\&H
M``!`^<`#7]8``(#2_7O!J,`#7]8?(`/5_7N[J?T#`)'S4P&ILP``L.$3`9%B
MXD?Y]5L"J14``+#W&P#YMZ(1D?8#`*K@`Q>J0P!`^>,G`/D#`(#25?S_EX``
M`+0!`$`Y]`,`JL$!`#7A`Q:JH*(1D;;\_Y=SXD?YX2=`^6`"0/D@``#*X`,`
MM?-30:GU6T*I]QM`^?U[Q:C``U_6X0,6JBCW_Y>`_O^UX`,6JD'V_Y?U`P"J
MX`,4JC[V_Y>@`@"+``@`D7/V_Y?F`Q2JY`,6J@4``+`#``"PI4`-D6.`#9$"
M`("2]0,`JB$`@%(U]O^7X0,5JN`#%ZJ4_/^7WO__%Z#V_Y<?(`/5$#J0TO]C
M,,NB``#00D``D0<"D-+D8R>+_7L!J?U#`)%(I$"I]5L#J;8``+#Y:P6I^@,`
MJOES`I'`XD?Y\U,"J>$#&:KW8P2I&```L.@G!VT%`$#YA=P`^04`@-(`PPR1
M2@Q`^>@G"JGJ6P#Y2"1"J>@G#:E&'$.IYA\.J4041*GD%P^I2BQ%J>JO"ZE"
M,$#YXF<`^0/\_Y>```"T`0!`.?,#`*IA(0`U^W,&J8W__Y?T`P"JH!P`M.`#
M%*K[]?^7`/A_TP`$`)$P]O^7A`)`.?L#`*JD`0`T%0``L/,#&ZJU`A*1'R`#
MU>`#$ZKC`Q6J`@"`DB$`@%+P]?^7<PH`D80>0#@D__\UX&M`^6`*`+3T8P.1
M`P``%("&0/C@"0"TX0,9JM_[_Y?S`P"J8/__M`$`0#DA__\T,/W_E^#^_S3@
M`Q.J1?;_E_,#`*I@"`"TX`,3JM7U_Y?T`P"JX`,;JM+U_Y<4`!0+E!(0$1<`
M`+"4?D"3X`,4J@3V_Y<)`&>>YP,;JN0#$ZKE8@V1`@"`DB$`@%(&``"P`P``
ML,8@$I%C0!*1Q?7_ER`!9IX!.(!2KO;_EQ\$`#&A``!4H_;_EP4`0+F_1`!Q
MP18`5"$!9I[U`P21X@,5J@``@%)?]O^7\P,`*N`%`#2@``"P)`%FGD,#0/GH
M`V>>`,Q'^0(``+`A`(!20H`3D0``0/DW]O^7^W-&J0$"D-+6XD?YX6,ABP`!
M9IXBW$#YP0)`^4$``<H!-0"U$#J0TOU[0:GS4T*I]5M#J?=C1*GY:T6IZ"='
M;?]C,(O``U_6]8,"D10`@%*SVG3XLP$`M&`"0#E@`0`TE`8`$>`#$ZK@_/^7
M(/__-.`#$ZKU]?^7\P,`JB#V_[6SVG3XL_[_M1,`@-*M__\7X!-!N0`,%!(?
M$$!QX?G_5/L;0;F5]?^7?P,`:V'Y_U3@$T&Y`"``$A\`!W'A^/]4X`,4JJWU
M_Y<(`&>>X0,9J@```+``X!21;OO_E\`/`+14`T#YV?7_E^$#`*K@`Q2JC/W_
ME_0#`*K@#@"TX`,4JF;U_Y?Y`P"J'PP`<>T!`%0`?$"3`0``L``0`-$A`!61
M@`(`B_'U_Y<``0`U/Q,`<8`E`%0@$P!1@,(@BP#P7S@?O`!QX"0`5,#^_Y?`
M```UX`,4J@$`@%(H]O^7^@,`*N`+`#4!``"P(8`1D0```+``X`Z1K_O_E_=B
M#9%[]?^7Y@,`*B0!9IX``6:>!P``L.?`&)'Y`P>JY0,7J@,``+`"`("28X`5
MD2$`@%(4``"P]0,7JCWU_Y>4PA61$0``%![V_Y<``$"Y'T0`<4$"`%1F]?^7
MY@,`*B0!9IX``6:>^0,`^7,&`!'G`Q,JY0,5JN,#%*H"`("2(0"`4BOU_Y<`
M`6:>`3B`4A3V_Y<?!``Q@/W_5"`!9I[0]?^7`0%FG@###)&#^_^7``%FGK7^
M_Y?[<T:I=/__%_7C`I$3`(!2H-IS^(`!`+1S!@`1X0,9JA#[_Y=@__^T`0!`
M.2'__S1Z]?^7]`,`J@#B_[6@VG/XP/[_M:`!@-)`]?^7%```L/L#`*ID"H!2
ME.(1D0___Q>@``"P)`%FGD,#0/GH`V>>`,Q'^0(``+`A`(!20H`2D0``0/F)
M]?^7^W-&J5+__Q>0_O^7X`,3JF#U_Y<(`&>>3?__%U0#0/F)__\70@"`4B$"
M@)+Y(P>12/7_E^$#&:K"`(#2X`,:*KCU_Y?@(T<Y@```->`G1SD?#`%QH!D`
M5`(`@%(!`(#2X`,:*COU_Y>@X@"1)6"$TB-QE=+"GYO2P8Z*TOSC!)'@0P#Y
M`#Z<TJ7HK/*C^;WR0A>S\D$&HO)`>KCRY0\0J>('$:G@DP#Y__\2J?][`;D"
M`)#2X0,9JN`#&BJ9]?^7^P,`JA\``''S`P`J30@`5.6+4JEA?T"3X'M!N:,,
M`0N_``/K0I2"FD%T08OCAQ*I@!$`-`$(@%(S``!+?P,3:^%#0/ESTY,:='Y`
MDR#`((OB`Q2JX0,9JJ;T_Y?@>T&Y8`(`"^![`;D?``%Q(?S_5',#$TO@`Q6J
M.P,4BW'V_Y=__@!Q[1``5',"`5%@?@93X(\`N11D&E.4`@&1=`,4BV8?0*F&
M'P"IX`,5JF(/0:F"#P&I>P,!D68??JF&'P*I8@]_J8(/`ZE>]O^7?P,4ZX'^
M_U3@CT"Y<QH`2^!#0/D#"8#28GY`D^$#%*J]]/^7\WL!N0(`D-+A`QFJX`,:
M*ECU_Y?[`P"J'P``<?,#`"H,^/]4X`,:*OKT_Y?AET#YX@^`$O,K0;GT,T&Y
M(2`#4W,*P%H@!``1E`K`6A_@`'&"RR$X+0L`5`((@%)"``!+`0"`4KGB`)%"
M?$"3(,,@B\#T_Y?@`Q6J-O;_E^!#")$?_#*IO_X$J;_^!:F_-@#YX`,5JO1S
M`;GS=P&Y+?;_E^8#!)'E`T&YXPM!N?IC!I'B$T&Y%0``L.$;0;FE",!:X"-!
MN6,(P%KD#T0Y0@C`6B$(P%K%#!`IP@01*;,"$I$`",!:6:,`D?0#&JKU!P:1
MX),!N0(``!2D%D`XX`,4JN,#$ZH"`("2(0"`4I0*`)%,]/^7/P,4ZP'__U0D
M`6:>``%FGN8#&JKE8@V1`@"`DB$`@%('``"P`P``L.?`&)%C0!61_P,'.3[T
M_Y<@`6:>Z/3_EP$!9IX`PPR1F_K_EP`!9I[-_?^7^W-&J8S^_Q?[`QFJA___
M%UD'0/DYV_^TX`,9JBOT_Y<?#`#QJ=K_5``0`-$!``"P(`,`BR$@%9&X]/^7
M'P``<902F9K-_O\7]`,;JH[__Q>CX@"1`@>`4D(``$L!`(!28,`@BT)\0)-H
M]/^7K___%^`K1SD?!`%Q0>;_5.`O1SD?#`%QX>7_5.`S1SD?(`%Q@>7_5.`W
M1SD?%`%Q(>7_5$(`@%(A!X"2X`,:*F/T_Y?A`QFJX`,:*B(%@-+3]/^7)`%F
MG@`!9I[F`QFJY6(-D0<``+`#``"PY\`8D6-`%9$"`("2(0"`4OSS_Y?6_O\7
M^W,&J6GT_Y?]>[BIH```L/T#`)'W8P.IN```L/-3`:D3UT?Y]5L"J0'@1_GY
M:P2I^W,%J?O3`9%@`D"Y(@!`^>(_`/D"`(#22/3_E_0#`*I@`D"Y1?3_EX'B
M0CD!Y`(Y````L.$#&ZH`8`Z1V?G_EX```+0!`$`Y/\0`<6`3`%30_/^7%]='
M^>`"0+DW]/^7`0``L&,!@%(A(!:1(@"`4DKT_Y?@%`"TO```T)8C`I'H)P9M
M\P)`N0`(0/G!!D"Y/P0`<0D40/W-!0!4&8"`4A4`@%(T`(!2&02@<@H``!0`
M`6:>00A`^5#T_Y?!!D"Y(`0`-90&`!&U!@`1/P`4:ZT#`%3@`Q,J&/3_ER$!
M9IX#`(!2HGY`DWST_Y?Z`P"J@!(`M`(`0/G#!D#Y0`Q`N?,"0+D``!D*'P`0
M<6C8=/P`_?]4X`,3*@CT_Y=!`T#Y0P"`4@(`@-+T\_^7X0,`J@`!9I[S`D"Y
M,/3_E\$&0+D@_/\T(`0`41\`%6O`"P!4Z"=&;>`#$RKX\_^78P"`4@$``+`B
M`(!2(4`6D0OT_Y?S`P"JH`$`M!371_F``D"Y[O/_EV$*0/D"``"P0F`6D2$`
M0/G)\_^78`I`^0``0/D`#$"YX`ZP-Q371_F``D"YXO/_EP$``+!C`(!2(8`6
MD2(`@%+U\_^7\P,`JJ`!`+0```"PX0,;J@``#9%Q^?^7]0,`JH`"0+G5"P"T
MT_/_EV$*0/GB`Q6J(0!`^:_S_Y<8UT?YE","D0`#0+G+\_^7\P,`J@`#0+G(
M\_^7(@"`4@$``+`AH!:1`/3_EP(``+#A`P"J0@`7D>`#$ZJ?\_^7``-`N;WS
M_Y<?Y`(YX0,;J@```+``P`R14OG_EX`*`/GS`P"JP`4`M`$X@%+@`Q.J/O3_
MEP$$`!$_!`!Q!(A1>@$)`%2@``"0&N!'^>$_0/E``T#Y(```R@`(`+7S4T&I
M]5M"J?=C0ZGY:T2I^W-%J?U[R*C``U_6``1`.<#L_S1D__\7/P0`<4WT_U06
MUT?YE2,"D30`@%("```4TP)`N>`#$RJ5\_^7(0%FGI0&`!%.\_^7H`9`N1\`
M%&L,__]4`-='^>@G1FT3`$"YDO__%[P``+#S`D"YC___%X`&0/GX_/^7@`H`
M^?,#`*K@^?^U````D``@%Y'H)P9MO_/_EP'71_F`(P*1,P!`N0$$0+D@!`!1
M'P`5:\'O_U3:__\7=O/_EX`C`I%B"D#Y`01`^4``0/DA`$#YAOK_EZ'__Q>`
M`D"Y;?/_EV$*0/DA`$#YPO/_EX7__Q?H)P9M=_/_EYPC`I'H)P9MXP,`*N(#
M$ZH```"0@0=`^0#`%Y$A`$#YGO/_EQ\@`]7]>[ZI_0,`D?-3`:GT`P"JIOO_
MEP$`0#GS`P"JP0``-``$`)$_O`!Q<Q*`F@$`0#F!__\U5_S_EY\"`/$$&$!Z
M@0``5/-30:G]>\*HP`-?UH`"0#F`__\T`0``D.`#$ZJ"`(#2(2`2D2;S_Y?`
M_O\UX`,4JO-30:G]>\*HS_G_%Z,``+!C!$#Y^O+_%Q\@`]7]>[RI_0,`D?37
M`:FT``"0M0``D)0B+)&U`BR1]M\"J90"%<OX'P#YE/Y#D_8#`"KW`P&J^`,"
MJJSR_Y>4`0"TLPL`^1,`@-*C>G/XX@,8JN$#%ZK@`Q8J<P8`D6``/]:?`A/K
M(?__5+,+0/GTUT&I]M]"J?@?0/G]>\2HP`-?UL`#7];]>[^I_0,`D?U[P:C`
M`U_6``````$``@``````<&5R;'AS:2YC`````````%]?14Y67U!!4E]#3$5!
M3E]?("`@("`@("`@("`@("`@```````````N`````````"XN````````)7,O
M)7,````O<')O8R]S96QF+V5X90``1'EN84QO861E<CHZ8F]O=%]$>6YA3&]A
M9&5R``````!);G1E<FYA;',Z.E!!4CHZ0D]/5`````!E>&4``````"]P<F]C
M+R5I+R5S``````!005)?5$5-4```````````4$%27U!23T=.04U%`````#H`
M````````+P`````````E<R5S)7,``%!%4DPU3$E"``````````!015),3$E"
M`%!%4DPU3U!4``````````!015),24\``%!!4E])3DE424%,25I%1`!005)?
M4U!!5TY%1```````4$%27T-,14%.`````````%!!4E]$14)51P````````!0
M05)?0T%#2$4`````````4$%27T=,3T)!3%]$14)51P``````````4$%27T=,
M3T)!3%]435!$25(`````````4$%27U1-4$1)4@```````%!!4E]'3$]"04Q?
M5$5-4`!005)?1TQ/0D%,7T-,14%.``````````!005)?0TQ%04X]````````
M,0````````!,1%],24)205)97U!!5$@`4UE35$5-```E,#)X`````'!A<BT`
M````)7,E<R5S)7,``````````"5S.B!C<F5A=&EO;B!O9B!P<FEV871E('-U
M8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H````````E<SH@<')I
M=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS869E("AP;&5A<V4@<F5M;W9E
M(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO;BD*````````4$%42`````!P
M87)L`````"YP87(`````)7,E<V-A8VAE+25S)7,``"5S)7-T96UP+25U)7,`
M```E<R5S=&5M<"TE=2TE=25S``````````!!4D=6`````!@`````````<&5R
M;``````P`````````%!!4CHZ4&%C:V5R.CI615)324].`````#$N,#0W````
M56YA8FQE('1O(&-R96%T92!C86-H92!D:7)E8W1O<GD``````````"5S.B!C
M<F5A=&EO;B!O9B!P<FEV871E(&-A8VAE('-U8F1I<F5C=&]R>2`E<R!F86EL
M960@*&5R<FYO/25I*0H``````````"5S````````+64````````M+0``````
M`%5315(`````55-%4DY!344``````````%1-4$1)4@``5$5-4$1)4@!414U0
M`````%1-4```````+W1M<`````!E=F%L("=E>&5C("]U<W(O8FEN+W!E<FP@
M("U3("0P("1[,2LB)$`B?2<*:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E<B!S
M;VUE('-H96QL"G!A8VMA9V4@7U]P87)?<&P["FUY("@D<&%R7W1E;7`L("1P
M<F]G;F%M92P@0'1M<&9I;&4I.PI%3D0@>R!I9B`H)$5.5GM005)?0TQ%04Y]
M*2!["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI"87-E;F%M
M93L*<F5Q=6ER92!&:6QE.CI3<&5C.PIM>2`D=&]P9&ER(#T@1FEL93HZ0F%S
M96YA;64Z.F1I<FYA;64H)'!A<E]T96UP*3L*;W5T<RAQ<7M296UO=FEN9R!F
M:6QE<R!I;B`B)'!A<E]T96UP(GTI.PI&:6QE.CI&:6YD.CIF:6YD9&5P=&@H
M<W5B('L@*"`M9"`I(#\@<FUD:7(@.B!U;FQI;FL@?2P@)'!A<E]T96UP*3L*
M<FUD:7(@)'!A<E]T96UP.PII9B`H+60@)'!A<E]T96UP("8F("1>3R!N92`G
M35-7:6XS,B<I('L*;7D@)'1M<"`](&YE=R!&:6QE.CI496UP*`I414U03$%4
M12`]/B`G=&UP6%A86%@G+`I$25(@/3X@1FEL93HZ0F%S96YA;64Z.F1I<FYA
M;64H)'1O<&1I<BDL"E-51D9)6"`]/B`G+F-M9"<L"E5.3$E.2R`]/B`P+`HI
M.PIP<FEN="`D=&UP("(C(2]B:6XO<V@*>#TQ.R!W:&EL92!;(%PD>"`M;'0@
M,3`@73L@9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF(%L@7"$@+60@)R1P87)?
M=&5M<"<@73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q"G@]8&5X<'(@7"1X("L@
M,6`*9&]N90IR;2`G(B`N("1T;7`M/F9I;&5N86UE("X@(B<*(CL*8VAM;V0@
M,#<P,"PD=&UP+3YF:6QE;F%M93L*;7D@)&-M9"`]("1T;7`M/F9I;&5N86UE
M("X@)R`^+V1E=B]N=6QL(#(^)C$@)B<["F-L;W-E("1T;7`["G-Y<W1E;2@D
M8VUD*3L*;W5T<RAQ<2A3<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P
M97)F;W)M(&-L96%N=7`Z("D*+B`D=&UP+3YF:6QE;F%M92D["GT*?2!]"D)%
M1TE.('L*26YT97)N86QS.CI005(Z.D)/3U0H*2!I9B!D969I;F5D("9);G1E
M<FYA;',Z.E!!4CHZ0D]/5#L*979A;"!["E]P87)?:6YI=%]E;G8H*3L*;7D@
M)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;7D@)4-O;F9I9R`]("@*<&%T
M:%]S97`@("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z("<Z)RDL"E]E
M>&4@("`@("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN*2\@
M/R`G+F5X92<@.B`G)RDL"E]D96QI;2`@("`@(#T^("@D7D\@/7X@+UY-4U=I
M;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL"BD["E]S971?<')O9VYA;64H*3L*7W-E
M=%]P87)?=&5M<"@I.PIM>2`H)'-T87)T7W!O<RP@)&1A=&%?<&]S*3L*>PIL
M;V-A;"`D4TE'>U]?5T%23E]??2`]('-U8B![?3L*;W!E;B!?1D@L("<\)RP@
M)'!R;V=N86UE(&]R(&QA<W0["F)I;FUO9&4H7T9(*3L*;7D@)&)U9CL*;7D@
M)'-I>F4@/2`M<R`D<')O9VYA;64["FUY("1O9F9S970@/2`U,3(["FUY("1I
M9'@@/2`M,3L*=VAI;&4@*#$I"GL*)&]F9G-E="`]("1S:7IE(&EF("1O9F9S
M970@/B`D<VEZ93L*<V5E:R!?1D@L("TD;V9F<V5T+"`R(&]R(&1I92!Q<5MS
M965K(&9A:6QE9"!O;B`B)'!R;V=N86UE(CH@)"%=.PIM>2`D;G)E860@/2!R
M96%D(%]&2"P@)&)U9BP@)&]F9G-E=#L*9&EE('%Q6W)E860@9F%I;&5D(&]N
M("(D<')O9VYA;64B.B`D(5T@=6YL97-S("1N<F5A9"`]/2`D;V9F<V5T.PHD
M:61X(#T@<FEN9&5X*"1B=68L(")<;E!!4BYP;5QN(BD["FQA<W0@:68@)&ED
M>"`^/2`P('Q\("1O9F9S970@/3T@)'-I>F4@?'P@)&]F9G-E="`^(#$R."`J
M(#$P,C0["B1O9F9S970@*CT@,CL*?0IL87-T('5N;&5S<R`D:61X(#X](#`[
M"B1O9F9S970@+3T@)&ED>"`M(#0["G-E96L@7T9(+"`M)&]F9G-E="P@,CL*
M<F5A9"!?1D@L("1B=68L(#0["G-E96L@7T9(+"`M)&]F9G-E="`M('5N<&%C
M:R@B3B(L("1B=68I+"`R.PIR96%D(%]&2"P@)&)U9BP@-#L*)&1A=&%?<&]S
M(#T@*'1E;&P@7T9(*2`M(#0["FUY("5R97%U:7)E7VQI<W0["G=H:6QE("@D
M8G5F(&5Q(")&24Q%(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L
M("1B=68L('5N<&%C:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA;64@/2`D8G5F
M.PIO=71S*'%Q*%5N<&%C:VEN9R!F:6QE("(D9G5L;&YA;64B+BXN*2D["FUY
M("1C<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_
M("0Q(#H@=6YD968["FUY("@D8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@
M;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B=68L(#0["G)E
M860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@*&1E9FEN960H
M)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["FUY
M("1F:6QE;F%M92`](%]T96UP9FEL92@B)&-R8R1E>'0B+"`D8G5F+"`P-S4U
M*3L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65](#T@)&9I;&5N
M86UE.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M97T@/2`D9G5L
M;&YA;64["GT*96QS:68@*"`D9G5L;&YA;64@/7X@;7Q>+S]S:&QI8B]\(&%N
M9"!D969I;F5D("1%3E9[4$%27U1%35!]("D@>PIM>2`D9FEL96YA;64@/2!?
M=&5M<&9I;&4H(B1B87-E;F%M921E>'0B+"`D8G5F+"`P-S4U*3L*;W5T<R@B
M4TA,24(Z("1F:6QE;F%M95QN(BD["GT*96QS92!["B1R97%U:7)E7VQI<W1[
M)&9U;&QN86UE?2`]"B1005(Z.DAE879Y.CI-;V1U;&5#86-H97LD9G5L;&YA
M;65](#T@>PIB=68@/3X@)&)U9BP*8W)C(#T^("1C<F,L"FYA;64@/3X@)&9U
M;&QN86UE+`I].PI]"G)E860@7T9(+"`D8G5F+"`T.PI]"FQO8V%L($!)3D,@
M/2`H<W5B('L*;7D@*"1S96QF+"`D;6]D=6QE*2`]($!?.PIR971U<FX@:68@
M<F5F("1M;V1U;&4@;W(@(21M;V1U;&4["FUY("1F:6QE;F%M92`](&1E;&5T
M92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5]('Q\(&1O('L*;7D@)&ME>3L*9F]R
M96%C:"`H:V5Y<R`E<F5Q=6ER95]L:7-T*2!["FYE>'0@=6YL97-S("]<421M
M;V1U;&5<120O.PHD:V5Y(#T@)%\[(&QA<W0["GT*9&5L971E("1R97%U:7)E
M7VQI<W1[)&ME>7T@:68@9&5F:6YE9"@D:V5Y*3L*?2!O<B!R971U<FX["B1)
M3D-[)&UO9'5L97T@/2`B+VQO861E<B\D9FEL96YA;64O)&UO9'5L92(["FEF
M("@D14Y6>U!!4E]#3$5!3GT@86YD(&1E9FEN960H)DE/.CI&:6QE.CIN97<I
M*2!["FUY("1F:"`]($E/.CI&:6QE+3YN97=?=&UP9FEL92!O<B!D:64@)"$[
M"F)I;FUO9&4H)&9H*3L*<')I;G0@)&9H("1F:6QE;F%M92T^>V)U9GT["G-E
M96LH)&9H+"`P+"`P*3L*<F5T=7)N("1F:#L*?0IE;'-E('L*;7D@)&9I;&5N
M86UE(#T@7W1E;7!F:6QE*"(D9FEL96YA;64M/GMC<F-]+G!M(BP@)&9I;&5N
M86UE+3Y[8G5F?2D["F]P96X@;7D@)&9H+"`G/"<L("1F:6QE;F%M92!O<B!D
M:64@(F-A;B=T(')E860@)&9I;&5N86UE.B`D(2(["F)I;FUO9&4H)&9H*3L*
M<F5T=7)N("1F:#L*?0ID:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C86YN
M;W0@9FEN9"`D;6]D=6QE(5QN(CL*?2P@0$E.0RD["G)E<75I<F4@6%-,;V%D
M97(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!#87)P.CI(96%V>3L*
M<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y
M;F%L;V%D97(H*3L*<F5Q=6ER92!)3SHZ1FEL93L*=VAI;&4@*&UY("1F:6QE
M;F%M92`]("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;,%TI('L*=6YL97-S
M("@D24Y#>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^("]"4T1004XO*2![
M"FEF("@D9FEL96YA;64@/7X@+UPN<&UC/R0O:2D@>PIR97%U:7)E("1F:6QE
M;F%M93L*?0IE;'-E('L*9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL96YA;64@
M/7X@+W-I=&5C=7-T;VUI>F5<+G!L)"\["GT*?0ID96QE=&4@)')E<75I<F5?
M;&ES='LD9FEL96YA;65].PI]"FQA<W0@=6YL97-S("1B=68@97$@(E!+7#`P
M,UPP,#0B.PHD<W1A<G1?<&]S(#T@*'1E;&P@7T9(*2`M(#0["GT*;7D@0'!A
M<E]A<F=S.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO9V9H+"`D8V%C:&5?;F%M
M92D["F1E;&5T92`D14Y6>U!!4E]!4%!?4D554T5].R`C('-A;FET:7IE("A2
M155312!M87D@8F4@82!S96-U<FET>2!P<F]B;&5M*0HD<75I970@/2`P('5N
M;&5S<R`D14Y6>U!!4E]$14)51WT["FEF("@A)'-T87)T7W!O<R!O<B`H)$%2
M1U9;,%T@97$@)RTM<&%R+6]P=&EO;G,G("8F('-H:69T*2D@>PIM>2`E9&ES
M=%]C;60@/2!Q=R@*<"`@(&)L:6)?=&]?<&%R"FD@("!I;G-T86QL7W!A<@IU
M("`@=6YI;G-T86QL7W!A<@IS("`@<VEG;E]P87(*=B`@('9E<FEF>5]P87(*
M*3L*:68@*$!!4D=6(&%N9"`D05)'5ELP72!E<2`G+2UR975S92<I('L*<VAI
M9G0@0$%21U8["B1%3E9[4$%27T%04%]2155317T@/2!S:&EF="!`05)'5CL*
M?0IE;'-E('L@(R!N;W)M86P@<&%R;"!B96AA=FEO=7(*;7D@0&%D9%]T;U]I
M;F,["G=H:6QE("A`05)'5BD@>PHD05)'5ELP72`]?B`O7BTH6T%)34]"3&)Q
M<&EU<U1V72DH+BHI+R!O<B!L87-T.PII9B`H)#$@97$@)TDG*2!["G!U<V@@
M0&%D9%]T;U]I;F,L("0R.PI]"F5L<VEF("@D,2!E<2`G32<I('L*979A;"`B
M=7-E("0R(CL*?0IE;'-I9B`H)#$@97$@)T$G*2!["G5N<VAI9G0@0'!A<E]A
M<F=S+"`D,CL*?0IE;'-I9B`H)#$@97$@)T\G*2!["B1O=70@/2`D,CL*?0IE
M;'-I9B`H)#$@97$@)V(G*2!["B1B=6YD;&4@/2`G<VET92<["GT*96QS:68@
M*"0Q(&5Q("=")RD@>PHD8G5N9&QE(#T@)V%L;"<["GT*96QS:68@*"0Q(&5Q
M("=Q)RD@>PHD<75I970@/2`Q.PI]"F5L<VEF("@D,2!E<2`G3"<I('L*;W!E
M;B`D;&]G9F@L("(^/B(L("0R(&]R(&1I92`B6%A8.B!#86YN;W0@;W!E;B!L
M;V<Z("0A(CL*?0IE;'-I9B`H)#$@97$@)U0G*2!["B1C86-H95]N86UE(#T@
M)#(["GT*<VAI9G0H0$%21U8I.PII9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD
M,7TI('L*9&5L971E("1%3E9[)U!!4E]414U0)WT["FEN:71?:6YC*"D["G)E
M<75I<F4@4$%2.CI$:7-T.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N;&5S
M<R!`05)'5CL*)GLB4$%2.CI$:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'5CL*
M97AI=#L*?0I]"G5N<VAI9G0@0$E.0RP@0&%D9%]T;U]I;F,["GT*?0II9B`H
M)&]U="D@>PI["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@07)C:&EV93HZ
M6FEP.PI]"FUY("1P87(@/2!S:&EF="A`05)'5BD["FUY("1Z:7`["FEF("AD
M969I;F5D("1P87(I('L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H,3(X
M*C$P,C0I.PIO<&5N(&UY("1F:"P@)SPG+"`D<&%R(&]R(&1I92`B0V%N;F]T
M(&9I;F0@)R1P87(G.B`D(2(["F)I;FUO9&4H)&9H*3L*8FQE<W,H)&9H+"`G
M24\Z.D9I;&4G*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M
M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII
M<#HZ05I?3TLH*2`I"F]R(&1I92`B4F5A9"`G)'!A<B<@97)R;W(Z("0A(CL*
M?0IM>2`E96YV(#T@9&\@>PII9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP
M+3YC;VYT96YT<R@G345402YY;6PG*2D@>PHD;65T82`]?B!S+RXJ7G!A<CHD
M+R]M<SL*)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M971A(#U^("]>("`H6UXZ
M72LI.B`H+BLI)"]M9SL*?0I].PIL;V-A;"`D+R`](%PT.PII9B`H9&5F:6YE
M9"`D<&%R*2!["F]P96X@4$%2+"`G/"<L("1P87(@;W(@9&EE("(D(3H@)'!A
M<B(["F)I;FUO9&4H4$%2*3L*9&EE("(D<&%R(&ES(&YO="!A(%!!4B!F:6QE
M(B!U;FQE<W,@/%!!4CX@97$@(E!+7#`P,UPP,#0B.PI]"D-R96%T95!A=&@H
M)&]U="D@.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`HD;W5T+`I)3SHZ1FEL
M93HZ3U]#4D5!5"@I('P@24\Z.D9I;&4Z.D]?5U)/3DQ9*"D@?"!)3SHZ1FEL
M93HZ3U]44E5.0R@I+`HP-S<W+`HI(&]R(&1I92`D(3L*8FEN;6]D92@D9F@I
M.PHD+R`]("AD969I;F5D("1D871A7W!O<RD@/R!<)&1A=&%?<&]S(#H@=6YD
M968["G-E96L@7T9(+"`P+"`P.PIM>2`D;&]A9&5R(#T@<V-A;&%R(#Q?1D@^
M.PII9B`H(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_
M.B,A?%Q`<F5M*2\I('L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`[
M"E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<)&QO861E<BP@
M)#`I"GT*9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@)65N=BD@>PIM>2`D
M=F%L(#T@)&5N=GLD:V5Y?2!O<B!N97AT.PHD=F%L(#T@979A;"`D=F%L(&EF
M("1V86P@/7X@+UY;)R)=+SL*;7D@)&UA9VEC(#T@(E]?14Y67U!!4E\B("X@
M=6,H)&ME>2D@+B`B7U\B.PIM>2`D<V5T(#T@(E!!4E\B("X@=6,H)&ME>2D@
M+B`B/21V86PB.PHD;&]A9&5R(#U^('-[)&UA9VEC*"`K*7U["B1M86=I8R`N
M("1S970@+B`H)R`G('@@*&QE;F=T:"@D,2D@+2!L96YG=&@H)'-E="DI*0I]
M96<["GT*)&9H+3YP<FEN="@D;&]A9&5R*3L*)"\@/2!U;F1E9CL*:68@*"1B
M=6YD;&4I('L*<F5Q=6ER92!005(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI
M=%]D>6YA;&]A9&5R*"D["FEN:71?:6YC*"D["G)E<75I<F5?;6]D=6QE<R@I
M.PIM>2!`:6YC(#T@9W)E<"![("$O0E-$4$%.+R!]"F=R97`@>PHH)&)U;F1L
M92!N92`G<VET92<I(&]R"B@D7R!N92`D0V]N9FEG.CI#;VYF:6=[87)C:&QI
M8F5X<'T@86YD"B1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB97AP?2D[
M"GT@0$E.0SL*;7D@)69I;&5S.PHD9FEL97-[)%]]*RL@9F]R($!$>6YA3&]A
M9&5R.CID;%]S:&%R961?;V)J96-T<RP@=F%L=65S("5)3D,["FUY("1L:6)?
M97AT(#T@)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1].PIM>2`E=W)I='1E;CL*
M9F]R96%C:"`H<V]R="!K97ES("5F:6QE<RD@>PIM>2`H)&YA;64L("1F:6QE
M*3L*9F]R96%C:"!M>2`D9&ER("A`:6YC*2!["FEF("@D;F%M92`]("1005(Z
M.DAE879Y.CI&=6QL0V%C:&5[)%]]*2!["B1F:6QE(#T@)%\["FQA<W0["GT*
M96QS:68@*"]>*%Q1)&1I<EQ%7"\H+BI;7D-C72DI7%HO:2D@>PHH)&9I;&4L
M("1N86UE*2`]("@D,2P@)#(I.PIL87-T.PI]"F5L<VEF("AM(5XO;&]A9&5R
M+UM>+UTK+R@N*EM>0V-=*5Q:(2D@>PII9B`H;7D@)')E9B`]("1005(Z.DAE
M879Y.CI-;V1U;&5#86-H97LD,7TI('L**"1F:6QE+"`D;F%M92D@/2`H)')E
M9BP@)#$I.PIL87-T.PI]"F5L<VEF("@M9B`B)&1I<B\D,2(I('L**"1F:6QE
M+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0["GT*?0I]"FYE>'0@
M=6YL97-S(&1E9FEN960@)&YA;64@86YD(&YO="`D=W)I='1E;GLD;F%M97TK
M*SL*;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D;&EB
M7V5X=%Q%)"\["F]U=',H(&IO:6X@(B(L"G%Q*%!A8VMI;F<@(BDL(')E9B`D
M9FEL92`_("1F:6QE+3Y[;F%M97T@.B`D9FEL92P*<7$H(BXN+BD**3L*;7D@
M)&-O;G1E;G0["FEF("AR968H)&9I;&4I*2!["B1C;VYT96YT(#T@)&9I;&4M
M/GMB=69].PI]"F5L<V4@>PIO<&5N($9)3$4L("<\)RP@)&9I;&4@;W(@9&EE
M(")#86XG="!O<&5N("1F:6QE.B`D(2(["F)I;FUO9&4H1DE,12D["B1C;VYT
M96YT(#T@/$9)3$4^.PIC;&]S92!&24Q%.PI005(Z.D9I;'1E<CHZ4&]D4W1R
M:7`M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92D*:68@(21%3E9[4$%2
M7U9%4D)!5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PI0
M05(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N
M="P@)&9I;&4L("1N86UE*3L*?0IO=71S*'%Q*%=R:71T96X@87,@(B1N86UE
M(BDI.PHD9F@M/G!R:6YT*")&24Q%(BD["B1F:"T^<')I;G0H<&%C:R@G3B<L
M(&QE;F=T:"@D;F%M92D@*R`Y*2D["B1F:"T^<')I;G0H<W!R:6YT9B@*(B4P
M.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL
M("1N86UE"BDI.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&-O;G1E
M;G0I*2D["B1F:"T^<')I;G0H)&-O;G1E;G0I.PI]"GT*)'II<"T^=W)I=&54
M;T9I;&5(86YD;&4H)&9H*2!I9B`D>FEP.PHD8V%C:&5?;F%M92`]('-U8G-T
M<B`D8V%C:&5?;F%M92P@,"P@-#`["FEF("@A)&-A8VAE7VYA;64@86YD(&UY
M("1M=&EM92`]("AS=&%T*"1O=70I*5LY72D@>PIM>2`D8W1X(#T@979A;"![
M(')E<75I<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@?0I\
M?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^
M;F5W('T*?'P@979A;"![(')E<75I<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ
M340U+3YN97<@?3L*;7D@)'-H85]V97)S:6]N(#T@979A;"![("1$:6=E<W0Z
M.E-(03HZ5D524TE/3B!]('Q\(#`["FEF("@D<VAA7W9E<G-I;VX@97$@)S4N
M,S@G(&]R("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I('L*)&-T>"T^861D9FEL
M92@D;W5T+"`B8B(I(&EF("@D8W1X*3L*?0IE;'-E('L*:68@*"1C='@@86YD
M(&]P96XH;7D@)&9H+"`B/"1O=70B*2D@>PIB:6YM;V1E*"1F:"D["B1C='@M
M/F%D9&9I;&4H)&9H*3L*8VQO<V4H)&9H*3L*?0I]"B1C86-H95]N86UE(#T@
M)&-T>"`_("1C='@M/FAE>&1I9V5S="`Z("1M=&EM93L*?0HD8V%C:&5?;F%M
M92`N/2`B7#`B('@@*#0Q("T@;&5N9W1H("1C86-H95]N86UE*3L*)&-A8VAE
M7VYA;64@+CT@(D-!0TA%(CL*)&9H+3YP<FEN="@D8V%C:&5?;F%M92D["B1F
M:"T^<')I;G0H<&%C:R@G3B<L("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R
M*2DI.PHD9F@M/G!R:6YT*")<;E!!4BYP;5QN(BD["B1F:"T^8VQO<V4["F-H
M;6]D(#`W-34L("1O=70["F5X:70["GT*>PIL87-T('5N;&5S<R!D969I;F5D
M("1S=&%R=%]P;W,["E]F:7A?<')O9VYA;64H*3L*<F5Q=6ER92!005(["E!!
M4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*>PIR97%U:7)E($9I;&4Z
M.D9I;F0["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1Z:7`@/2!!<F-H
M:79E.CI::7`M/FYE=SL*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL*)&9H+3YF
M9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE("(D(3H@)$`B.PHD>FEP
M+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<')O9VYA;64I(#T]($%R8VAI
M=F4Z.EII<#HZ05I?3TLH*2!O<B!D:64@(B0A.B`D0"(["G!U<V@@0%!!4CHZ
M3&EB0V%C:&4L("1Z:7`["B1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D
M>FEP.PHD<75I970@/2`A)$5.5GM005)?1$5"54=].PIO=71S*'%Q*%PD14Y6
M>U!!4E]414U0?2`]("(D14Y6>U!!4E]414U0?2(I*3L*:68@*&1E9FEN960@
M)$5.5GM005)?5$5-4'TI('L@(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I
M;G0A"F9O<F5A8V@@;7D@)&UE;6)E<B`H("1Z:7`M/FUE;6)E<G,@*2!["FYE
M>'0@:68@)&UE;6)E<BT^:7-$:7)E8W1O<GD["FUY("1M96UB97)?;F%M92`]
M("1M96UB97(M/F9I;&5.86UE.PIN97AT('5N;&5S<R`D;65M8F5R7VYA;64@
M/7X@;7L*7@HO/W-H;&EB+PHH/SHD0V]N9FEG.CI#;VYF:6=[=F5R<VEO;GTO
M*3\**#\Z)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PHH6UXO72LI"B0*
M?7@["FUY("1E>'1R86-T7VYA;64@/2`D,3L*;7D@)&1E<W1?;F%M92`]($9I
M;&4Z.E-P96,M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL("1E>'1R86-T7VYA
M;64I.PII9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M96UB97(M/G5N
M8V]M<')E<W-E9%-I>F4H*2D@>PIO=71S*'%Q*%-K:7!P:6YG("(D;65M8F5R
M7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N86UE
M(BDI.PI](&5L<V4@>PIO=71S*'%Q*$5X=')A8W1I;F<@(B1M96UB97)?;F%M
M92(@=&\@(B1D97-T7VYA;64B*2D["B1M96UB97(M/F5X=')A8W14;T9I;&5.
M86UE9"@D9&5S=%]N86UE*3L*8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@
M)%Y/(&5Q(")H<'5X(CL*?0I]"GT*?0IU;FQE<W,@*"1005(Z.DQI8D-A8VAE
M>R1P<F]G;F%M97TI('L*9&EE(#P\("(N(B!U;FQE<W,@0$%21U8["E5S86=E
M.B`D,"!;("U!;&EB+G!A<B!=(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S
M<F,N<&%R(%T@6R!P<F]G<F%M+G!L(%T*)#`@6R`M0GPM8B!=(%LM3V]U=&9I
M;&5=('-R8RYP87(*+@HD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64@
M/2`D,"`]('-H:69T*$!!4D=6*3L*?0IS=6(@0W)E871E4&%T:"!["FUY("@D
M;F%M92D@/2!`7SL*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*;7D@*"1B87-E
M;F%M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S
M92@D;F%M92P@*"=<+BXJ)RDI.PIR97%U:7)E($9I;&4Z.E!A=&@["D9I;&4Z
M.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S*"UE("1P871H*3L@(R!M:W!A
M=&@@9&EE<R!W:71H(&5R<F]R"GT*<W5B(')E<75I<F5?;6]D=6QE<R!["G)E
M<75I<F4@;&EB.PIR97%U:7)E($1Y;F%,;V%D97(["G)E<75I<F4@:6YT96=E
M<CL*<F5Q=6ER92!S=')I8W0["G)E<75I<F4@=V%R;FEN9W,["G)E<75I<F4@
M=F%R<SL*<F5Q=6ER92!#87)P.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U
M:7)E($5R<FYO.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*<F5Q=6ER92!%
M>'!O<G1E<CL*<F5Q=6ER92!&8VYT;#L*<F5Q=6ER92!&:6QE.CI496UP.PIR
M97%U:7)E($9I;&4Z.E-P96,["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@
M0V]N9FEG.PIR97%U:7)E($E/.CI(86YD;&4["G)E<75I<F4@24\Z.D9I;&4[
M"G)E<75I<F4@0V]M<')E<W,Z.EIL:6(["G)E<75I<F4@07)C:&EV93HZ6FEP
M.PIR97%U:7)E(%!!4CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E(%!!
M4CHZ1&ES=#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["G)E<75I
M<F4@4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N=#L*<F5Q=6ER92!A='1R:6)U
M=&5S.PIE=F%L('L@<F5Q=6ER92!#=V0@?3L*979A;"![(')E<75I<F4@5VEN
M,S(@?3L*979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL('T["F5V86P@>R!R
M97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PIE=F%L('L@<F5Q=6ER
M92!4:64Z.DAA<V@Z.DYA;65D0V%P='5R92!].PIE=F%L('L@<F5Q=6ER92!0
M97)L24\[(')E<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*979A;"![(')E<75I
M<F4@=71F."!].PI]"G-U8B!?<V5T7W!A<E]T96UP('L*:68@*&1E9FEN960@
M)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+RD@
M>PHD<&%R7W1E;7`@/2`D,3L*<F5T=7)N.PI]"F9O<F5A8V@@;7D@)'!A=&@@
M*`HH;6%P("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$25(@5$5-4$1)
M4B!414U0(%1-4"`I*2P*<7<H($,Z7%Q414U0("]T;7`@+B`I"BD@>PIN97AT
M('5N;&5S<R!D969I;F5D("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A
M=&@["FUY("1U<V5R;F%M93L*;7D@)'!W=6ED.PIE=F%L('LH)'!W=6ED*2`]
M(&=E='!W=6ED*"0^*2!I9B!D969I;F5D("0^.WT["FEF("@@9&5F:6YE9"@F
M5VEN,S(Z.DQO9VEN3F%M92D@*2!["B1U<V5R;F%M92`]("97:6XS,CHZ3&]G
M:6Y.86UE.PI]"F5L<VEF("AD969I;F5D("1P=W5I9"D@>PHD=7-E<FYA;64@
M/2`D<'=U:60["GT*96QS92!["B1U<V5R;F%M92`]("1%3E9[55-%4DY!345]
M('Q\("1%3E9[55-%4GT@?'P@)U-94U1%32<["GT*)'5S97)N86UE(#U^(',O
M7%<O7R]G.PIM>2`D<W1M<&1I<B`]("(D<&%T:"1#;VYF:6=[7V1E;&EM?7!A
M<BTB+G5N<&%C:R@B2"HB+"`D=7-E<FYA;64I.PIM:V1I<B`D<W1M<&1I<BP@
M,#<U-3L*:68@*"$D14Y6>U!!4E]#3$5!3GT@86YD(&UY("1M=&EM92`]("AS
M=&%T*"1P<F]G;F%M92DI6SE=*2!["F]P96X@*&UY("1F:"P@(CPB+B`D<')O
M9VYA;64I.PIS965K("1F:"P@+3$X+"`R.PIS>7-R96%D("1F:"P@;7D@)&)U
M9BP@-CL*:68@*"1B=68@97$@(EPP0T%#2$4B*2!["G-E96L@)&9H+"`M-3@L
M(#(["G-Y<W)E860@)&9H+"`D8G5F+"`T,3L*)&)U9B`]?B!S+UPP+R]G.PHD
M<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M(B`N("1B=68["GT*
M96QS92!["FUY("1C='@@/2!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03L@
M1&EG97-T.CI32$$M/FYE=R@Q*2!]"GQ\(&5V86P@>R!R97%U:7)E($1I9V5S
M=#HZ4TA!,3L@1&EG97-T.CI32$$Q+3YN97<@?0I\?"!E=F%L('L@<F5Q=6ER
M92!$:6=E<W0Z.DU$-3L@1&EG97-T.CI-1#4M/FYE=R!].PIM>2`D<VAA7W9E
M<G-I;VX@/2!E=F%L('L@)$1I9V5S=#HZ4TA!.CI615)324].('T@?'P@,#L*
M:68@*"1S:&%?=F5R<VEO;B!E<2`G-2XS."<@;W(@)'-H85]V97)S:6]N(&5Q
M("<U+C,Y)RD@>PHD8W1X+3YA9&1F:6QE*"1P<F]G;F%M92P@(F(B*2!I9B`H
M)&-T>"D["GT*96QS92!["FEF("@D8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD
M<')O9VYA;64B*2D@>PIB:6YM;V1E*"1F:"D["B1C='@M/F%D9&9I;&4H)&9H
M*3L*8VQO<V4H)&9H*3L*?0I]"B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI
M;7UC86-H92TB("X@*"`D8W1X(#\@)&-T>"T^:&5X9&EG97-T(#H@)&UT:6UE
M("D["GT*8VQO<V4H)&9H*3L*?0IE;'-E('L*)$5.5GM005)?0TQ%04Y](#T@
M,3L*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?71E;7`M)"0B.PI]"B1%
M3E9[4$%27U1%35!](#T@)'-T;7!D:7(["FUK9&ER("1S=&UP9&ER+"`P-S4U
M.PIL87-T.PI]"B1P87)?=&5M<"`]("0Q(&EF("1%3E9[4$%27U1%35!](&%N
M9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\["GT*<W5B(%]T96UP9FEL92![
M"FUY("@D;F%M92P@)&-O;G1E;G1S+"`D;6]D92D@/2!`7SL*;7D@)&9U;&QN
M86UE(#T@(B1P87)?=&5M<"\D;F%M92(["G5N;&5S<R`H+64@)&9U;&QN86UE
M*2!["FUY("1T96UP;F%M92`]("(D9G5L;&YA;64N)"0B.PIO<&5N(&UY("1F
M:"P@)SXG+"`D=&5M<&YA;64@;W(@9&EE(")C86XG="!W<FET92`D=&5M<&YA
M;64Z("0A(CL*8FEN;6]D92`D9F@["G!R:6YT("1F:"`D8V]N=&5N=',["F-L
M;W-E("1F:#L*8VAM;V0@)&UO9&4L("1T96UP;F%M92!I9B!D969I;F5D("1M
M;V1E.PIR96YA;64H)'1E;7!N86UE+"`D9G5L;&YA;64I(&]R('5N;&EN:R@D
M=&5M<&YA;64I.PI]"G)E='5R;B`D9G5L;&YA;64["GT*<W5B(%]S971?<')O
M9VYA;64@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@86YD("1%
M3E9[4$%27U!23T=.04U%?2`]?B`O*"XK*2\I('L*)'!R;V=N86UE(#T@)#$[
M"GT*)'!R;V=N86UE('Q\/2`D,#L*:68@*"1%3E9[4$%27U1%35!](&%N9"!I
M;F1E>"@D<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P*2!["B1P<F]G
M;F%M92`]('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O9VYA;64L("1#
M;VYF:6=[7V1E;&EM?2D@*R`Q*3L*?0II9B`H(21%3E9[4$%27U!23T=.04U%
M?2!O<B!I;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/CT@,"D@
M>PII9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["G)E='5R;B!I
M9B`M<R`D9F@["GT*:68@*"US("(D<')O9VYA;64D0V]N9FEG>U]E>&5](BD@
M>PHD<')O9VYA;64@+CT@)$-O;F9I9WM?97AE?3L*<F5T=7)N.PI]"GT*9F]R
M96%C:"!M>2`D9&ER("AS<&QI="`O7%$D0V]N9FEG>W!A=&A?<V5P?5Q%+RP@
M)$5.5GM0051(?2D@>PIN97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A
M;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0?3L*)&1I<B`]?B!S+UQ1)$-O;F9I
M9WM?9&5L:6U]7$4D+R\["B@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D
M96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](BDL(&QA<W0I"FEF("US("(D
M9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(["B@H
M)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B*2P@
M;&%S="D*:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PI]
M"GT*<W5B(%]F:7A?<')O9VYA;64@>PHD,"`]("1P<F]G;F%M92!\?#T@)$5.
M5GM005)?4%)/1TY!345].PII9B`H:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG
M>U]D96QI;7TI(#P@,"D@>PHD<')O9VYA;64@/2`B+B1#;VYF:6=[7V1E;&EM
M?21P<F]G;F%M92(["GT*;7D@)'!W9"`]("AD969I;F5D("9#=V0Z.F=E=&-W
M9"D@/R!#=V0Z.F=E=&-W9"@I"CH@*"AD969I;F5D("97:6XS,CHZ1V5T0W=D
M*2`_(%=I;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*8VAO;7`H)'!W9"D["B1P
M<F]G;F%M92`]?B!S+UXH/SU<+EPN/UQ1)$-O;F9I9WM?9&5L:6U]7$4I+R1P
M=V0D0V]N9FEG>U]D96QI;7TO.PHD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O
M9VYA;64["GT*<W5B(%]P87)?:6YI=%]E;G8@>PII9B`H("1%3E9[4$%27TE.
M251)04Q)6D5$?2LK(#T](#$@*2!["G)E='5R;CL*?2!E;'-E('L*)$5.5GM0
M05)?24Y)5$E!3$E:141](#T@,CL*?0IF;W(@*'%W*"!34$%73D5$(%1%35`@
M0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!344@05)'0R!!4D=67S`@*2`I('L*
M9&5L971E("1%3E9[)U!!4E\G+B1??3L*?0IF;W(@*'%W+R!435!$25(@5$5-
M4"!#3$5!3B!$14)51R`O*2!["B1%3E9[)U!!4E\G+B1??2`]("1%3E9[)U!!
M4E]'3$]"04Q?)RXD7WT@:68@97AI<W1S("1%3E9[)U!!4E]'3$]"04Q?)RXD
M7WT["GT*;7D@)'!A<E]C;&5A;B`](")?7T5.5E]005)?0TQ%04Y?7R`@("`@
M("`@("`@("`@("(["FEF("@D14Y6>U!!4E]414U0?2D@>PID96QE=&4@)$5.
M5GM005)?0TQ%04Y].PI]"F5L<VEF("@A97AI<W1S("1%3E9[4$%27T=,3T)!
M3%]#3$5!3GTI('L*;7D@)'9A;'5E(#T@<W5B<W1R*"1P87)?8VQE86XL(#$R
M("L@;&5N9W1H*")#3$5!3B(I*3L*)$5.5GM005)?0TQ%04Y](#T@)#$@:68@
M)'9A;'5E(#U^("]>4$%27T-,14%./2A<4RLI+SL*?0I]"G-U8B!O=71S('L*
M<F5T=7)N(&EF("1Q=6EE=#L*:68@*"1L;V=F:"D@>PIP<FEN="`D;&]G9F@@
M(D!?7&XB.PI]"F5L<V4@>PIP<FEN="`B0%]<;B(["GT*?0IS=6(@:6YI=%]I
M;F,@>PIR97%U:7)E($-O;F9I9SL*<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L
M(&UA<"`D0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*87)C:&QI8F5X<"!P<FEV
M;&EB97AP('-I=&5A<F-H97AP('-I=&5L:6)E>'`*=F5N9&]R87)C:&5X<"!V
M96YD;W)L:6)E>'`**3L*?0IP86-K86=E(&UA:6X["G)E<75I<F4@4$%2.PIU
M;G-H:69T($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A
M<E]A<F=S*3L*9&EE('%Q*'!A<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP
M="`B)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN*0IU
M;FQE<W,@+64@)'!R;V=N86UE.PID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H
M)#$I(&EF("@D0"`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I
M9B`D0#L*?3L*)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]"D-/4D4Z.F5X:70H
M)#$I(&EF("@D.CI?7T524D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*
M9&EE("0Z.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*,3L*7U]%3D1?7PH`````
M``$;`SO<````&@```#B.__^,!@``T)#___0`````D?__"`$``#B1__\<`0``
M@)'__T`!``"(D?__6`$``&"B__]\`0``6*/__^0!````I/__%`(``$"F__]D
M`@``N*?__]`"``!0J/__^`(``("I__\X`P``N*G__U@#```0JO__?`,``.BJ
M__^T`P``\*K__\@#````K?__,`0``#"M__]$!```4*[__W@$```8L/__L`0`
M`*"P___8!```T+#__P`%``#`L?__-`4``)BZ___D!0``B+[__UP&````````
M$``````````!>E(`!'@>`1L,'P`0````&````-2/__\L`````````!`````L
M````\(___S@`````````(````$`````4D/__2`````!!#B"=!)X#0I,"3M[=
MTPX`````%````&0````XD/__!```````````````(````'P````HD/__U!``
M``!!#J`%1IU4GE,#+`0*W=X.`$$+9````*````#<H/__]`````!!#D"=")X'
M0I,&E`5#F`&7`D26`Y4$5];50=C70][=T]0.`$$.0),&E`65!)8#EP*8`9T(
MG@=/UM5!V-=!WMW3U`X`00Y`DP:4!9T(G@="EP*8`4+8UP`L````"`$``&RA
M__^H`````$$.0)T(G@="E026`T23!I0%80K>W=76T]0.`$$+``!,````.`$`
M`.2A__]``@```$$.<)T.G@U"DPR4"T.5"I8)2Y<(F`>9!IH%`D`*WMW9VM?8
MU=;3U`X`00M)FP1@"MM!"TK;0IL$1-M#FP0``&@```"(`0``U*/__W0!````
M00[@`9T<GAM"DQJ4&4>6%Y481-;51][=T]0.`$$.X`&3&I09E1B6%YT<GAM$
MF!67%D6:$YD4=`K6U4'8UT':V4$+0]76U]C9VD&6%Y4809@5EQ9!FA.9%```
M`"0```#T`0``X*3__Y0`````00ZP`9T6GA5#DQ24$U<*WMW3U`X`00L\````
M'`(``%"E__\P`0```$(.T"!"G8H$GHD$0I.(!)2'!$.5A@26A01"EX0$F(,$
M:0K=WM?8U=;3U`X`00L`'````%P"``!`IO__.`````!!#A"=`IX!2-[=#@``
M```@````?`(``%BF__]4`````$$.()T$G@-"DP)*WMW3#@`````T````H`(`
M`(RF___8`````$(.T$!"G8H(GHD(0I.(")2'"$.5A@B6A0AK"MW>U=;3U`X`
M00L``!````#8`@``+*?__P0`````````9````.P"```@I___#`(```!"#O`A
M09V>!)Z=!$*7F`28EP1#DYP$E)L$0YN4!%P*W=[;U]C3U`X`00M"EID$E9H$
M0IJ5!)F6!'P*UM5!VME!"U36U4':V4*6F025F@1!FI4$F98$```0````5`,`
M`,BH__\L`````````#````!H`P``Y*C__QP!````0@X@G02>`T*3`E@*WMW3
M#@!""V`*WMW3#@!!"T/>W=,.```T````G`,``-"I___$`0```$$.@`&=$)X/
M1),.E`U&E0R6"Y<*F`D"4`K>W=?8U=;3U`X`00L``"0```#4`P``8*O__X@`
M````00XPG0:>!4*3!)0#4`K>W=/4#@!!"P`D````_`,``,"K__\L`````$$.
M$)T"G@%%"M[=#@!""T+>W0X`````,````"0$``#(J___[`````!!#E"="IX)
M0I,(E`=$E0:6!4*7!%<*WMW7U=;3U`X`00L``*P```!8!```A*S__]@(````
M0@[0@P)%G;@@GK<@0Y6T():S($*9L"":KR!&D[8@E+4@E[(@F+$@4P5(K"`%
M2:L@1IRM()NN(`):W-M0!D@&2=W>V=K7V-76T]0.`$$.T(,"D[8@E+4@E;0@
MEK,@E[(@F+$@F;`@FJ\@FZX@G*T@G;@@GK<@!4BL(`5)JR`">PK<VT$+8=S;
M1INN()RM(`+`"MS;00MZV]Q!G*T@FZX@=`````@%``"LM/__[`,```!!#H`!
MG1">#T.7"I@)0I,.E`U%E0R6"YD(F@>;!IP%8`5)`P5(!'0&209(`E@*WMW;
MW-G:U]C5UM/4#@!!"T,%2`0%20-1!DD&2$T%20,%2`1)!D@&24\*!4D#!4@$
M00M"!4D#!4@$+````(`%```DN/__@`````!!#B"=!)X#0I,"E`%0"M[=T]0.
M`$$+2][=T]0.````0````+`%``"DA___2`(```!!#G"=#IX-0I,,E`MOE@F5
M"D&7"`)""M;50==!WMW3U`X`00M5U=;70I8)E0I!EP@`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!()``````````D
M`````````0`````````!``````````$`````````RP$````````!````````
M`-8!`````````0````````#@`0````````$`````````+P(````````!````
M`````(@#`````````0````````"P`P````````P`````````R!P````````-
M`````````&12````````&0``````````FP$``````!L`````````"```````
M```:``````````B;`0``````'``````````(`````````/7^_V\`````F`(`
M```````%`````````,`-````````!@````````"(`P````````H`````````
M%04````````+`````````!@`````````%0````````````````````,`````
M````8)T!```````"```````````&````````%``````````'`````````!<`
M````````R!8````````'`````````!`4````````"`````````"X`@``````
M``D`````````&``````````>``````````@`````````^___;P`````!```(
M`````/[__V\`````L!,```````#___]O``````,`````````\/__;P````#6
M$@```````/G__V\`````$```````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````.`<````````
MX!P```````#@'````````.`<````````X!P```````#@'````````.`<````
M````X!P```````#@'````````.`<````````X!P```````#@'````````.`<
M````````X!P```````#@'````````.`<````````X!P```````#@'```````
M`.`<````````X!P```````#@'````````.`<````````X!P```````#@'```
M`````.`<````````X!P```````#@'````````.`<````````X!P```````#@
M'````````.`<````````X!P```````#@'````````.`<````````X!P`````
M``#@'````````.`<````````X!P```````#@'````````.`<````````X!P`
M``````#@'````````.`<````````X!P```````#@'````````.`<````````
MX!P```````#@'````````.`<````````X!P```````#@'````````.`<````
M````X!P```````#@'````````.`<````````X!P```````#@'````````.`<
M````````X!P```````#@'````````.`<````````X!P```````#@'```````
M`.`<````````$)L!``````!@4@``````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````.!1````````````````````(0``````````````````````````
M````````````````````````"*`!``````#_____`````(A6````````N%(`
M`````````````````!A4````````:%8```````!P5@```````'A6````````
M@%8``````````````````%!6````````6%8``````````````````)!6````
M````1T-#.B`H1&5B:6%N(#@N,BXP+3<I(#@N,BXP`$=#0SH@*$1E8FEA;B`W
M+C,N,"TR."D@-RXS+C```"YS:'-T<G1A8@`N:6YT97)P`"YN;W1E+D%"22UT
M86<`+FYO=&4N9VYU+F)U:6QD+6ED`"YG;G4N:&%S:``N9'EN<WEM`"YD>6YS
M='(`+F=N=2YV97)S:6]N`"YG;G4N=F5R<VEO;E]R`"YR96QA+F1Y;@`N<F5L
M82YP;'0`+FEN:70`+G1E>'0`+F9I;FD`+G)O9&%T80`N96A?9G)A;65?:&1R
M`"YE:%]F<F%M90`N:6YI=%]A<G)A>0`N9FEN:5]A<G)A>0`N9'EN86UI8P`N
M9V]T`"YD871A`"YB<W,`+F-O;6UE;G0`````````````````````````````
M````````````````````````````````````````````````````````````
M````"P````$````"`````````#@"````````.`(````````;````````````
M`````````0```````````````````!,````'`````@````````!4`@``````
M`%0"````````(`````````````````````0````````````````````A````
M!P````(`````````=`(```````!T`@```````"0````````````````````$
M````````````````````-````/;__V\"`````````)@"````````F`(`````
M``#L``````````4`````````"````````````````````#X````+`````@``
M``````"(`P```````(@#````````.`H````````&`````P````@`````````
M&`````````!&`````P````(`````````P`T```````#`#0```````!4%````
M```````````````!````````````````````3@```/___V\"`````````-82
M````````UA(```````#:``````````4``````````@`````````"````````
M`%L```#^__]O`@````````"P$P```````+`3````````8``````````&````
M`P````@```````````````````!J````!`````(`````````$!0````````0
M%````````+@"````````!0`````````(`````````!@`````````=`````0`
M``!"`````````,@6````````R!8`````````!@````````4````5````"```
M```````8`````````'X````!````!@````````#('````````,@<````````
M%`````````````````````0```````````````````!Y`````0````8`````
M````X!P```````#@'````````"`$```````````````````0`````````!``
M````````A`````$````&```````````A`````````"$```````!D,0``````
M````````````"````````````````````(H````!````!@````````!D4@``
M`````&12````````$`````````````````````0```````````````````"0
M`````0````(`````````>%(```````!X4@```````%!`````````````````
M```(````````````````````F`````$````"`````````,B2````````R)(`
M``````#<````````````````````!````````````````````*8````!````
M`@````````"HDP```````*B3````````]`4```````````````````@`````
M``````````````"P````#@````,``````````)L!````````FP````````@`
M```````````````````(``````````@`````````O`````\````#````````
M``B;`0``````")L````````(````````````````````"``````````(````
M`````,@````&`````P`````````0FP$``````!";````````4`(````````&
M``````````@`````````$`````````#1`````0````,`````````8)T!````
M``!@G0```````*`"```````````````````(``````````@`````````U@``
M``$````#``````````"@`0```````*````````"`````````````````````
M"````````````````````-P````(`````P````````"`H`$``````("@````
M````*!````````````````````@```````````````````#A`````0```#``
M``````````````````"`H````````#D````````````````````!````````
M``$``````````0````,`````````````````````````N:````````#J````
<`````````````````0``````````````````````
